@@ -6,7 +6,7 @@ Music box. 5 voices randomly choosing frequencies over a common scale.
 """
 from pyo import *
 
-s = Server().boot()
+s = Server(duplex=0).boot()
 
 low_freqs = [midiToHz(m+7) for m in [36,43.01,48,55.01,60]]
 mid_freqs = [midiToHz(m+7) for m in [60,62,63.93,65,67.01,69,71,72]]
@@ -18,4 +18,4 @@ port = Port(chx, risetime=.001, falltime=.001)
 sines = SineLoop(port, feedback=[.06,.057,.033,.035,.016], mul=[.15,.15,.1,.1,.06])
 pan = SPan(sines, pan=[0, 1, .2, .8, .5]).out()
 
-s.gui(locals())
+s.gui(locals())
\ No newline at end of file
