@@ -21,7 +21,7 @@
 #include "Python.h"
 #include <math.h>
 
-#define PYO_VERSION "0.6.6"
+#define PYO_VERSION "0.6.8"
 
 #ifndef __MYFLT_DEF
 #define __MYFLT_DEF
@@ -63,6 +63,8 @@
 #define TYPE_OO_FI "OO|fi"
 #define TYPE_OO_IF "OO|if"
 #define TYPE_OOO_F "OOO|f"
+#define TYPE_OOO_FI "OOO|fi"
+#define TYPE_OO_OF "OO|Of"
 #define TYPE_OOO_FFFFII "OOO|ffffii"
 #define TYPE_O_FFFFII "O|ffffii"
 #define TYPE_F_O "f|O"
@@ -72,6 +74,7 @@
 #define TYPE__FIIOO "|fiiOO"
 #define TYPE_O_OFOO "O|OfOO"
 #define TYPE_O_IFFO "O|iffO"
+#define TYPE_O_OOIF "O|OOif"
 #define TYPE_O_FFFFIOO "O|ffffiOO"
 #define TYPE_OO_FOO "OO|fOO"
 #define TYPE_OO_FFOO "OO|ffOO"
@@ -140,6 +143,8 @@
 #define TYPE_OO_FI "OO|di"
 #define TYPE_OO_IF "OO|id"
 #define TYPE_OOO_F "OOO|d"
+#define TYPE_OOO_FI "OOO|di"
+#define TYPE_OO_OF "OO|Od"
 #define TYPE_OOO_FFFFII "OOO|ddddii"
 #define TYPE_O_FFFFII "O|ddddii"
 #define TYPE_F_O "d|O"
@@ -149,6 +154,7 @@
 #define TYPE__FIIOO "|diiOO"
 #define TYPE_O_OFOO "O|OdOO"
 #define TYPE_O_IFFO "O|iddO"
+#define TYPE_O_OOIF "O|OOid"
 #define TYPE_O_FFFFIOO "O|ddddiOO"
 #define TYPE_OO_FOO "OO|dOO"
 #define TYPE_OO_FFOO "OO|ddOO"
@@ -423,6 +429,32 @@ extern PyTypeObject SVFType;
 extern PyTypeObject AverageType;
 extern PyTypeObject CvlVerbType;
 extern PyTypeObject SpectrumType;
+extern PyTypeObject ResonType;
+extern PyTypeObject ResonxType;
+extern PyTypeObject ButLPType;
+extern PyTypeObject ButHPType;
+extern PyTypeObject ButBPType;
+extern PyTypeObject ButBRType;
+extern PyTypeObject PVAnalType;
+extern PyTypeObject PVSynthType;
+extern PyTypeObject PVTransposeType;
+extern PyTypeObject PVVerbType;
+extern PyTypeObject PVGateType;
+extern PyTypeObject PVAddSynthType;
+extern PyTypeObject PVCrossType;
+extern PyTypeObject PVMultType;
+extern PyTypeObject PVMorphType;
+extern PyTypeObject PVFilterType;
+extern PyTypeObject PVDelayType;
+extern PyTypeObject PVBufferType;
+extern PyTypeObject PVShiftType;
+extern PyTypeObject PVAmpModType;
+extern PyTypeObject PVFreqModType;
+extern PyTypeObject PVBufLoopsType;
+extern PyTypeObject PVBufTabLoopsType;
+extern PyTypeObject PVMixType;
+extern PyTypeObject GranuleType;
+extern PyTypeObject TableScaleType;
 
 /* Constants */
 #define E M_E
@@ -964,6 +996,14 @@ extern PyTypeObject SpectrumType;
     Py_INCREF(self->matrixstream); \
     return (PyObject *)self->matrixstream; \
 
+#define GET_PV_STREAM \
+    if (self->pv_stream == NULL) { \
+        PyErr_SetString(PyExc_TypeError, "No pv stream founded!"); \
+        return PyInt_FromLong(-1); \
+    } \
+    Py_INCREF(self->pv_stream); \
+    return (PyObject *)self->pv_stream;
+
 #define SET_MUL \
     PyObject *tmp, *streamtmp; \
  \
