@@ -16,6 +16,10 @@
  *                                                                        *
  * You should have received a copy of the GNU General Public License      *
  * along with pyo.  If not, see <http://www.gnu.org/licenses/>.           *
+ *                                                                        *
+ * Octobre 2013 : Multiple servers facility and embeded backend added by  *
+ * Guillaume Barrette. See embeded possibilities at:                      *
+ * https://github.com/guibarrette/PyoPlug                                 *
  *************************************************************************/
 
 #ifndef Py_SERVERMODULE_H
@@ -42,7 +46,8 @@ typedef enum {
     PyoCoreaudio = 1,
     PyoJack,
     PyoOffline,
-    PyoOfflineNB
+    PyoOfflineNB,
+    PyoEmbedded
 } PyoAudioBackendType;
 
 typedef struct {
@@ -63,7 +68,10 @@ typedef struct {
     PyoAudioBackendType audio_be_type;
     void *audio_be_data;
     char *serverName; /* Only used for jack client name */
+    int jackautoin; /* jack port auto-connection (on by default) */
+    int jackautoout; /* jack port auto-connection (on by default) */
     PmStream *in;
+    PmStream *out;
     PmEvent midiEvents[200];
     int midi_count;
     double samplingRate;
@@ -72,13 +80,18 @@ typedef struct {
     int duplex;
     int input;
     int output;
+    int input_offset;
+    int output_offset;
     int midi_input;
+    int midi_output;
     int withPortMidi;
+    int withPortMidiOut;
     int server_started;
     int server_stopped; /* for fadeout */
     int server_booted;
     int stream_count;
     int record;
+    int thisServerID;       /* To keep the reference index in the array of servers */
     
     /* global amplitude */
     MYFLT amp;
