@@ -29,30 +29,16 @@ class Clip(PyoObject):
     """
     Clips a signal to a predefined limit.
     
-    Parentclass : PyoObject
+    :Parent: :py:class:`PyoObject`
 
-    Parameters:
+    :Args:
     
-    input : PyoObject
-        Input signal to process.
-    min : float or PyoObject, optional
-        Minimum possible value. Defaults to -1.
-    max : float or PyoObject, optional
-        Maximum possible value. Defaults to 1.
-
-    Methods:
-
-    setInput(x, fadetime) : Replace the `input` attribute.
-    setMin(x) : Replace the `min` attribute.
-    setMax(x) : Replace the `max` attribute.
-
-    Attributes:
-    
-    input : PyoObject. Input signal to process.
-    min : float or PyoObject. Minimum possible value.
-    max : float or PyoObject. Maximum possible value.
-    
-    Examples:
+        input : PyoObject
+            Input signal to process.
+        min : float or PyoObject, optional
+            Minimum possible value. Defaults to -1.
+        max : float or PyoObject, optional
+            Maximum possible value. Defaults to 1.
     
     >>> s = Server().boot()
     >>> s.start()
@@ -63,29 +49,24 @@ class Clip(PyoObject):
 
     """
     def __init__(self, input, min=-1.0, max=1.0, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._min = min
         self._max = max
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, min, max, mul, add, lmax = convertArgsToLists(self._in_fader, min, max, mul, add)
         self._base_objs = [Clip_base(wrap(in_fader,i), wrap(min,i), wrap(max,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['input', 'min', 'max', 'mul', 'add']
-
     def setInput(self, x, fadetime=0.05):
         """
         Replace the `input` attribute.
         
-        Parameters:
+        :Args:
 
-        x : PyoObject
-            New signal to process.
-        fadetime : float, optional
-            Crossfade time between old and new input. Defaults to 0.05.
+            x : PyoObject
+                New signal to process.
+            fadetime : float, optional
+                Crossfade time between old and new input. Defaults to 0.05.
 
         """
         self._input = x
@@ -95,10 +76,10 @@ class Clip(PyoObject):
         """
         Replace the `min` attribute.
         
-        Parameters:
+        :Args:
 
-        x : float or PyoObject
-            New `min` attribute.
+            x : float or PyoObject
+                New `min` attribute.
 
         """
         self._min = x
@@ -109,10 +90,10 @@ class Clip(PyoObject):
         """
         Replace the `max` attribute.
         
-        Parameters:
+        :Args:
 
-        x : float or PyoObject
-            New `max` attribute.
+            x : float or PyoObject
+                New `max` attribute.
 
         """
         self._max = x
@@ -153,34 +134,20 @@ class Mirror(PyoObject):
     This object is useful for table indexing or for clipping and
     modeling an audio signal.
 
-    Parentclass : PyoObject
+    :Parent: :py:class:`PyoObject`
 
-    Parameters:
+    :Args:
 
-    input : PyoObject
-        Input signal to process.
-    min : float or PyoObject, optional
-        Minimum possible value. Defaults to 0.
-    max : float or PyoObject, optional
-        Maximum possible value. Defaults to 1.
+        input : PyoObject
+            Input signal to process.
+        min : float or PyoObject, optional
+            Minimum possible value. Defaults to 0.
+        max : float or PyoObject, optional
+            Maximum possible value. Defaults to 1.
 
-    Methods:
-
-    setInput(x, fadetime) : Replace the `input` attribute.
-    setMin(x) : Replace the `min` attribute.
-    setMax(x) : Replace the `max` attribute.
-
-    Attributes:
-
-    input : PyoObject. Input signal to process.
-    min : float or PyoObject. Minimum possible value.
-    max : float or PyoObject. Maximum possible value.
-
-    Notes:
+    .. note::
     
-    If `min` is higher than `max`, then the output will be the average of the two.
-    
-    Examples:
+        If `min` is higher than `max`, then the output will be the average of the two.
 
     >>> s = Server().boot()
     >>> s.start()
@@ -192,29 +159,24 @@ class Mirror(PyoObject):
 
     """
     def __init__(self, input, min=0.0, max=1.0, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._min = min
         self._max = max
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, min, max, mul, add, lmax = convertArgsToLists(self._in_fader, min, max, mul, add)
         self._base_objs = [Mirror_base(wrap(in_fader,i), wrap(min,i), wrap(max,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['input', 'min', 'max', 'mul', 'add']
-
     def setInput(self, x, fadetime=0.05):
         """
         Replace the `input` attribute.
 
-        Parameters:
+        :Args:
 
-        x : PyoObject
-            New signal to process.
-        fadetime : float, optional
-            Crossfade time between old and new input. Defaults to 0.05.
+            x : PyoObject
+                New signal to process.
+            fadetime : float, optional
+                Crossfade time between old and new input. Defaults to 0.05.
 
         """
         self._input = x
@@ -224,10 +186,10 @@ class Mirror(PyoObject):
         """
         Replace the `min` attribute.
 
-        Parameters:
+        :Args:
 
-        x : float or PyoObject
-            New `min` attribute.
+            x : float or PyoObject
+                New `min` attribute.
 
         """
         self._min = x
@@ -238,143 +200,10 @@ class Mirror(PyoObject):
         """
         Replace the `max` attribute.
 
-        Parameters:
+        :Args:
 
-        x : float or PyoObject
-            New `max` attribute.
-
-        """
-        self._max = x
-        x, lmax = convertArgsToLists(x)
-        [obj.setMax(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
-
-    def ctrl(self, map_list=None, title=None, wxnoserver=False):
-        self._map_list = [SLMap(0., 1., 'lin', 'min', self._min),
-                          SLMap(0., 1., 'lin', 'max', self._max),
-                          SLMapMul(self._mul)]
-        PyoObject.ctrl(self, map_list, title, wxnoserver)
-
-    @property
-    def input(self):
-        """PyoObject. Input signal to process.""" 
-        return self._input
-    @input.setter
-    def input(self, x): self.setInput(x)
-
-    @property
-    def min(self):
-        """float or PyoObject. Minimum possible value.""" 
-        return self._min
-    @min.setter
-    def min(self, x): self.setMin(x)
-
-    @property
-    def max(self):
-        """float or PyoObject. Maximum possible value.""" 
-        return self._max
-    @max.setter
-    def max(self, x): self.setMax(x)
-
-class Wrap(PyoObject):
-    """
-    Wraps-around the signal that exceeds the `min` and `max` thresholds.
-
-    This object is useful for table indexing, phase shifting or for 
-    clipping and modeling an audio signal.
-
-    Parentclass : PyoObject
-
-    Parameters:
-
-    input : PyoObject
-        Input signal to process.
-    min : float or PyoObject, optional
-        Minimum possible value. Defaults to 0.
-    max : float or PyoObject, optional
-        Maximum possible value. Defaults to 1.
-
-    Methods:
-
-    setInput(x, fadetime) : Replace the `input` attribute.
-    setMin(x) : Replace the `min` attribute.
-    setMax(x) : Replace the `max` attribute.
-
-    Attributes:
-
-    input : PyoObject. Input signal to process.
-    min : float or PyoObject. Minimum possible value.
-    max : float or PyoObject. Maximum possible value.
-
-    Notes:
-
-    If `min` is higher than `max`, then the output will be the average of the two.
-
-    Examples:
-
-    >>> s = Server().boot()
-    >>> s.start()
-    >>> # Time-varying overlaping envelopes
-    >>> env = HannTable()
-    >>> lff = Sine(.5, mul=3, add=4)
-    >>> ph1 = Phasor(lff)
-    >>> ph2 = Wrap(ph1+0.5, min=0, max=1)
-    >>> amp1 = Pointer(env, ph1, mul=.25)
-    >>> amp2 = Pointer(env, ph2, mul=.25)
-    >>> a = SineLoop(250, feedback=.1, mul=amp1).out()
-    >>> b = SineLoop(300, feedback=.1, mul=amp2).out(1)
-
-    """
-    def __init__(self, input, min=0.0, max=1.0, mul=1, add=0):
-        PyoObject.__init__(self)
-        self._input = input
-        self._min = min
-        self._max = max
-        self._mul = mul
-        self._add = add
-        self._in_fader = InputFader(input)
-        in_fader, min, max, mul, add, lmax = convertArgsToLists(self._in_fader, min, max, mul, add)
-        self._base_objs = [Wrap_base(wrap(in_fader,i), wrap(min,i), wrap(max,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
-
-    def __dir__(self):
-        return ['input', 'min', 'max', 'mul', 'add']
-
-    def setInput(self, x, fadetime=0.05):
-        """
-        Replace the `input` attribute.
-
-        Parameters:
-
-        x : PyoObject
-            New signal to process.
-        fadetime : float, optional
-            Crossfade time between old and new input. Defaults to 0.05.
-
-        """
-        self._input = x
-        self._in_fader.setInput(x, fadetime)
-
-    def setMin(self, x):
-        """
-        Replace the `min` attribute.
-
-        Parameters:
-
-        x : float or PyoObject
-            New `min` attribute.
-
-        """
-        self._min = x
-        x, lmax = convertArgsToLists(x)
-        [obj.setMin(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
-
-    def setMax(self, x):
-        """
-        Replace the `max` attribute.
-
-        Parameters:
-
-        x : float or PyoObject
-            New `max` attribute.
+            x : float or PyoObject
+                New `max` attribute.
 
         """
         self._max = x
@@ -415,32 +244,18 @@ class Degrade(PyoObject):
     Degrade takes an audio signal and reduces the sampling rate and/or 
     bit-depth as specified.
     
-    Parentclass : PyoObject
+    :Parent: :py:class:`PyoObject`
 
-    Parameters:
+    :Args:
     
-    input : PyoObject
-        Input signal to process.
-    bitdepth : float or PyoObject, optional
-        Signal quantization in bits. Must be in range 1 -> 32.
-        Defaults to 16.
-    srscale : float or PyoObject, optional
-        Sampling rate multiplier. Must be in range 0.0009765625 -> 1.
-        Defaults to 1.
-
-    Methods:
-
-    setInput(x, fadetime) : Replace the `input` attribute.
-    setBitdepth(x) : Replace the `bitdepth` attribute.
-    setSrscale(x) : Replace the `srscale` attribute.
-
-    Attributes:
-    
-    input : PyoObject. Input signal to process.
-    bitdepth : float or PyoObject. Quantization in bits.
-    srscale : float or PyoObject. Sampling rate multiplier.
-    
-    Examples:
+        input : PyoObject
+            Input signal to process.
+        bitdepth : float or PyoObject, optional
+            Signal quantization in bits. Must be in range 1 -> 32.
+            Defaults to 16.
+        srscale : float or PyoObject, optional
+            Sampling rate multiplier. Must be in range 0.0009765625 -> 1.
+            Defaults to 1.
     
     >>> s = Server().boot()
     >>> s.start()
@@ -452,29 +267,24 @@ class Degrade(PyoObject):
     
     """
     def __init__(self, input, bitdepth=16, srscale=1.0, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._bitdepth = bitdepth
         self._srscale = srscale
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, bitdepth, srscale, mul, add, lmax = convertArgsToLists(self._in_fader, bitdepth, srscale, mul, add)
         self._base_objs = [Degrade_base(wrap(in_fader,i), wrap(bitdepth,i), wrap(srscale,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['input', 'bitdepth', 'srscale', 'mul', 'add']
-
     def setInput(self, x, fadetime=0.05):
         """
         Replace the `input` attribute.
         
-        Parameters:
+        :Args:
 
-        x : PyoObject
-            New signal to process.
-        fadetime : float, optional
-            Crossfade time between old and new input. Defaults to 0.05.
+            x : PyoObject
+                New signal to process.
+            fadetime : float, optional
+                Crossfade time between old and new input. Defaults to 0.05.
 
         """
         self._input = x
@@ -484,10 +294,10 @@ class Degrade(PyoObject):
         """
         Replace the `bitdepth` attribute.
         
-        Parameters:
+        :Args:
 
-        x : float or PyoObject
-            New `bitdepth` attribute.
+            x : float or PyoObject
+                New `bitdepth` attribute.
 
         """
         self._bitdepth = x
@@ -498,10 +308,10 @@ class Degrade(PyoObject):
         """
         Replace the `srscale` attribute.
         
-        Parameters:
+        :Args:
 
-        x : float or PyoObject
-            New `srscale` attribute.
+            x : float or PyoObject
+                New `srscale` attribute.
 
         """
         self._srscale = x
@@ -542,59 +352,42 @@ class Compress(PyoObject):
     Compress reduces the volume of loud sounds or amplifies quiet sounds by 
     narrowing or compressing an audio signal's dynamic range.
 
-    Parentclass: PyoObject
+    :Parent: :py:class:`PyoObject`
 
-    Parameters:
+    :Args:
 
-    input : PyoObject
-        Input signal to process.
-    thresh : float or PyoObject, optional
-        Level, expressed in dB, above which the signal is reduced. 
-        Reference level is 0dB. Defaults to -20.
-    ratio : float or PyoObject, optional
-        Determines the input/output ratio for signals above the 
-        threshold. Defaults to 2.
-    risetime : float or PyoObject, optional
-        Used in amplitude follower, time to reach upward value in 
-        seconds. Defaults to 0.01.
-    falltime : float or PyoObject, optional
-        Used in amplitude follower, time to reach downward value in 
-        seconds. Defaults to 0.1.
-    lookahead : float, optional
-        Delay length, in ms, for the "look-ahead" buffer. Range is
-        0 -> 25 ms. Defaults to 5.0.
-    knee : float optional
-        Shape of the transfert function around the threshold, specified
-        in the range 0 -> 1. A value of 0 means a hard knee and a value 
-        of 1.0 means a softer knee. Defaults to 0.
-    outputAmp : boolean, optional
-        If True, the object's output signal will be the compression level
-        alone, not the compressed signal. It can be useful if 2 or more
-        channels need to linked on the same compression slope. Available
-        at initialization only. Defaults to False.
-        
-    Methods:
+        input : PyoObject
+            Input signal to process.
+        thresh : float or PyoObject, optional
+            Level, expressed in dB, above which the signal is reduced. 
+            Reference level is 0dB. Defaults to -20.
+        ratio : float or PyoObject, optional
+            Determines the input/output ratio for signals above the 
+            threshold. Defaults to 2.
+        risetime : float or PyoObject, optional
+            Used in amplitude follower, time to reach upward value in 
+            seconds. Defaults to 0.01.
+        falltime : float or PyoObject, optional
+            Used in amplitude follower, time to reach downward value in 
+            seconds. Defaults to 0.1.
+        lookahead : float, optional
+            Delay length, in ms, for the "look-ahead" buffer. Range is
+            0 -> 25 ms. Defaults to 5.0.
+        knee : float optional
+            Shape of the transfert function around the threshold, specified
+            in the range 0 -> 1. 
+            
+            A value of 0 means a hard knee and a value of 1.0 means a softer 
+            knee. Defaults to 0.
+        outputAmp : boolean, optional
+            If True, the object's output signal will be the compression level
+            alone, not the compressed signal. 
+            
+            It can be useful if 2 or more channels need to linked on the same 
+            compression slope. Defaults to False.
+            
+            Available at initialization only. 
 
-    setInput(x, fadetime) : Replace the `input` attribute.
-    setThresh(x) : Replace the `thresh` attribute.
-    setRatio(x) : Replace the `ratio` attribute.
-    setRiseTime(x) : Replace the `risetime` attribute.
-    setFallTime(x) : Replace the `falltime` attribute.
-    setLookAhead(x) : Replace the `lookahead` attribute.
-    setKnee(x) : Replace the `knee` attribute.
-    
-    Attributes:
-    
-    input : PyoObject. Input signal to process.
-    thresh : float or PyoObject. Level above which the signal is reduced.
-    ratio : float or PyoObject. in/out ratio for signals above the threshold.
-    risetime : float or PyoObject. Time to reach upward value in seconds.
-    falltime : float or PyoObject. Time to reach downward value in seconds.
-    lookahead : float. Delay length, in ms, for the "look-ahead" buffer.
-    knee : float. Shape of the transfert function around the threshold.
-     
-    Examples:
-    
     >>> s = Server().boot()
     >>> s.start()
     >>> a = SfPlayer(SNDS_PATH + '/transparent.aif', loop=True)
@@ -602,7 +395,7 @@ class Compress(PyoObject):
     
     """
     def __init__(self, input, thresh=-20, ratio=2, risetime=0.01, falltime=0.1, lookahead=5.0, knee=0, outputAmp=False, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._thresh = thresh
         self._ratio = ratio
@@ -610,25 +403,20 @@ class Compress(PyoObject):
         self._falltime = falltime
         self._lookahead = lookahead
         self._knee = knee
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, thresh, ratio, risetime, falltime, lookahead, knee, outputAmp, mul, add, lmax = convertArgsToLists(self._in_fader, thresh, ratio, risetime, falltime, lookahead, knee, outputAmp, mul, add)
         self._base_objs = [Compress_base(wrap(in_fader,i), wrap(thresh,i), wrap(ratio,i), wrap(risetime,i), wrap(falltime,i), wrap(lookahead,i), wrap(knee,i), wrap(outputAmp,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['input', 'thresh', 'ratio', 'risetime', 'falltime', 'lookahead', 'knee', 'mul', 'add']
-
     def setInput(self, x, fadetime=0.05):
         """
         Replace the `input` attribute.
         
-        Parameters:
+        :Args:
 
-        x : PyoObject
-            New signal to process.
-        fadetime : float, optional
-            Crossfade time between old and new input. Defaults to 0.05.
+            x : PyoObject
+                New signal to process.
+            fadetime : float, optional
+                Crossfade time between old and new input. Defaults to 0.05.
 
         """
         self._input = x
@@ -638,10 +426,10 @@ class Compress(PyoObject):
         """
         Replace the `thresh` attribute.
         
-        Parameters:
+        :Args:
 
-        x : float or PyoObject
-            New `thresh` attribute.
+            x : float or PyoObject
+                New `thresh` attribute.
 
         """
         self._thresh = x
@@ -652,10 +440,10 @@ class Compress(PyoObject):
         """
         Replace the `ratio` attribute.
         
-        Parameters:
+        :Args:
 
-        x : float or PyoObject
-            New `ratio` attribute.
+            x : float or PyoObject
+                New `ratio` attribute.
 
         """
         self._ratio = x
@@ -666,10 +454,10 @@ class Compress(PyoObject):
         """
         Replace the `risetime` attribute.
         
-        Parameters:
+        :Args:
 
-        x : float or PyoObject
-            New `risetime` attribute.
+            x : float or PyoObject
+                New `risetime` attribute.
 
         """
         self._risetime = x
@@ -680,10 +468,10 @@ class Compress(PyoObject):
         """
         Replace the `falltime` attribute.
         
-        Parameters:
+        :Args:
 
-        x : float or PyoObject
-            New `falltime` attribute.
+            x : float or PyoObject
+                New `falltime` attribute.
 
         """
         self._falltime = x
@@ -694,10 +482,10 @@ class Compress(PyoObject):
         """
         Replace the `lookahead` attribute.
 
-        Parameters:
+        :Args:
 
-        x : float
-            New `lookahead` attribute.
+            x : float
+                New `lookahead` attribute.
 
         """
         self._lookahead = x
@@ -708,10 +496,10 @@ class Compress(PyoObject):
         """
         Replace the `knee` attribute.
 
-        Parameters:
+        :Args:
 
-        x : float
-            New `knee` attribute.
+            x : float
+                New `knee` attribute.
 
         """
         self._knee = x
@@ -763,7 +551,7 @@ class Compress(PyoObject):
     
     @property
     def lookahead(self):
-        """float. Delay length, in ms, for the "look-ahead" buffer."""
+        """float. Delay length, in ms, of the "look-ahead" buffer."""
         return self._lookahead
     @lookahead.setter
     def lookahead(self, x): self.setLookAhead(x)
@@ -785,45 +573,30 @@ class Gate(PyoObject):
     from the signal. When the gate is open both the signal and the noise will 
     pass through.
     
-    Parentclass: PyoObject
+    :Parent: :py:class:`PyoObject`
 
-    Parameters:
+    :Args:
 
-    input : PyoObject
-        Input signal to process.
-    thresh : float or PyoObject, optional
-        Level, expressed in dB, below which the gate is closed. 
-        Reference level is 0dB. Defaults to -70.
-    risetime : float or PyoObject, optional
-        Time to open the gate in seconds. Defaults to 0.01.
-    falltime : float or PyoObject, optional
-        Time to close the gate in seconds. Defaults to 0.05.
-    lookahead : float, optional
-        Delay length, in ms, for the "look-ahead" buffer. Range is
-        0 -> 25 ms. Defaults to 5.0.
-    outputAmp : boolean, optional
-        If True, the object's output signal will be the gating level
-        alone, not the gated signal. It can be useful if 2 or more
-        channels need to linked on the same gating slope. Available
-        at initialization only. Defaults to False.
-
-    Methods:
-
-    setInput(x, fadetime) : Replace the `input` attribute.
-    setThresh(x) : Replace the `thresh` attribute.
-    setRiseTime(x) : Replace the `risetime` attribute.
-    setFallTime(x) : Replace the `falltime` attribute.
-    setLookAhead(x) : Replace the `lookahead` attribute.
-
-    Attributes:
-
-    input : PyoObject. Input signal to process.
-    thresh : float or PyoObject. Level below which the gate is closed.
-    risetime : float or PyoObject. Time to open the gate in seconds.
-    falltime : float or PyoObject. Time to close the gate in seconds.
-    lookahead : float. Delay length, in ms, for the "look-ahead" buffer.
-
-    Examples:
+        input : PyoObject
+            Input signal to process.
+        thresh : float or PyoObject, optional
+            Level, expressed in dB, below which the gate is closed. 
+            Reference level is 0dB. Defaults to -70.
+        risetime : float or PyoObject, optional
+            Time to open the gate in seconds. Defaults to 0.01.
+        falltime : float or PyoObject, optional
+            Time to close the gate in seconds. Defaults to 0.05.
+        lookahead : float, optional
+            Delay length, in ms, for the "look-ahead" buffer. Range is
+            0 -> 25 ms. Defaults to 5.0.
+        outputAmp : boolean, optional
+            If True, the object's output signal will be the gating level
+            alone, not the gated signal. 
+            
+            It can be useful if 2 or more channels need to linked on the 
+            same gating slope. Defaults to False.
+            
+            Available at initialization only.
 
     >>> s = Server().boot()
     >>> s.start()
@@ -832,31 +605,26 @@ class Gate(PyoObject):
 
     """
     def __init__(self, input, thresh=-70, risetime=0.01, falltime=0.05, lookahead=5.0, outputAmp=False, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._thresh = thresh
         self._risetime = risetime
         self._falltime = falltime
         self._lookahead = lookahead
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, thresh, risetime, falltime, lookahead, outputAmp, mul, add, lmax = convertArgsToLists(self._in_fader, thresh, risetime, falltime, lookahead, outputAmp, mul, add)
         self._base_objs = [Gate_base(wrap(in_fader,i), wrap(thresh,i), wrap(risetime,i), wrap(falltime,i), wrap(lookahead,i), wrap(outputAmp,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['input', 'thresh', 'risetime', 'falltime', 'lookahead', 'mul', 'add']
-
     def setInput(self, x, fadetime=0.05):
         """
         Replace the `input` attribute.
 
-        Parameters:
+        :Args:
 
-        x : PyoObject
-            New signal to process.
-        fadetime : float, optional
-            Crossfade time between old and new input. Defaults to 0.05.
+            x : PyoObject
+                New signal to process.
+            fadetime : float, optional
+                Crossfade time between old and new input. Defaults to 0.05.
 
         """
         self._input = x
@@ -866,10 +634,10 @@ class Gate(PyoObject):
         """
         Replace the `thresh` attribute.
 
-        Parameters:
+        :Args:
 
-        x : float or PyoObject
-            New `thresh` attribute.
+            x : float or PyoObject
+                New `thresh` attribute.
 
         """
         self._thresh = x
@@ -880,10 +648,10 @@ class Gate(PyoObject):
         """
         Replace the `risetime` attribute.
 
-        Parameters:
+        :Args:
 
-        x : float or PyoObject
-            New `risetime` attribute.
+            x : float or PyoObject
+                New `risetime` attribute.
 
         """
         self._risetime = x
@@ -894,10 +662,10 @@ class Gate(PyoObject):
         """
         Replace the `falltime` attribute.
 
-        Parameters:
+        :Args:
 
-        x : float or PyoObject
-            New `falltime` attribute.
+            x : float or PyoObject
+                New `falltime` attribute.
 
         """
         self._falltime = x
@@ -908,10 +676,10 @@ class Gate(PyoObject):
         """
         Replace the `lookahead` attribute.
 
-        Parameters:
+        :Args:
 
-        x : float
-            New `lookahead` attribute.
+            x : float
+                New `lookahead` attribute.
 
         """
         self._lookahead = x
@@ -955,7 +723,270 @@ class Gate(PyoObject):
 
     @property
     def lookahead(self):
-        """float. Delay length, in ms, for the "look-ahead" buffer."""
+        """float. Delay length, in ms, of the "look-ahead" buffer."""
         return self._lookahead
     @lookahead.setter
     def lookahead(self, x): self.setLookAhead(x)
+
+class Balance(PyoObject):
+    """
+    Adjust rms power of an audio signal according to the rms power of another.
+
+    The rms power of a signal is adjusted to match that of a comparator signal.
+
+    :Parent: :py:class:`PyoObject`
+
+    :Args:
+
+        input : PyoObject
+            Input signal to process.
+        input2 : PyoObject
+            Comparator signal.
+        freq : float or PyoObject, optional
+            Cutoff frequency of the lowpass filter in hertz. Default to 10.
+
+    >>> s = Server().boot()
+    >>> s.start()
+    >>> sf = SfPlayer(SNDS_PATH + '/accord.aif', speed=[.99,1], loop=True, mul=.3)
+    >>> comp = SfPlayer(SNDS_PATH + '/transparent.aif', speed=[.99,1], loop=True, mul=.3)
+    >>> out = Balance(sf, comp, freq=10).out()
+
+    """
+    def __init__(self, input, input2, freq=10, mul=1, add=0):
+        PyoObject.__init__(self, mul, add)
+        self._input = input
+        self._input2 = input2
+        self._freq = freq
+        self._in_fader = InputFader(input)
+        self._in_fader2 = InputFader(input2)
+        in_fader, in_fader2, freq, mul, add, lmax = convertArgsToLists(self._in_fader, self._in_fader2, freq, mul, add)
+        self._base_objs = [Balance_base(wrap(in_fader,i), wrap(in_fader2,i), wrap(freq,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
+
+    def setInput(self, x, fadetime=0.05):
+        """
+        Replace the `input` attribute.
+        
+        Input signal to process.
+
+        :Args:
+
+            x : PyoObject
+                New signal to process.
+            fadetime : float, optional
+                Crossfade time between old and new input. Default to 0.05.
+
+        """
+        self._input = x
+        self._in_fader.setInput(x, fadetime)
+
+    def setInput2(self, x, fadetime=0.05):
+        """
+        Replace the `input2` attribute.
+        
+        Comparator signal.
+
+        :Args:
+
+            x : PyoObject
+                New signal to process.
+            fadetime : float, optional
+                Crossfade time between old and new input. Default to 0.05.
+
+        """
+        self._input2 = x
+        self._in_fader2.setInput(x, fadetime)
+
+    def setFreq(self, x):
+        """
+        Replace the `freq` attribute.
+        
+        Cutoff frequency of the lowpass filter, in Hertz.
+
+        :Args:
+
+            x : float or PyoObject
+                New `freq` attribute.
+
+        """
+        self._freq = x
+        x, lmax = convertArgsToLists(x)
+        [obj.setFreq(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
+
+    def ctrl(self, map_list=None, title=None, wxnoserver=False):
+        self._map_list = [SLMap(0.1, 100., "log", "freq", self._freq), SLMapMul(self._mul)]
+        PyoObject.ctrl(self, map_list, title, wxnoserver)
+
+    @property
+    def input(self):
+        """PyoObject. Input signal to process.""" 
+        return self._input
+    @input.setter
+    def input(self, x): self.setInput(x)
+
+    @property
+    def input2(self):
+        """PyoObject. Comparator signal.""" 
+        return self._input2
+    @input2.setter
+    def input2(self, x): self.setInput2(x)
+
+    @property
+    def freq(self):
+        """float or PyoObject. Cutoff frequency of the lowpass filter.""" 
+        return self._freq
+    @freq.setter
+    def freq(self, x): self.setFreq(x)
+
+class Min(PyoObject):
+    """
+    Outputs the minimum of two values.
+ 
+    :Parent: :py:class:`PyoObject`
+   
+    :Args:
+    
+        input : PyoObject
+            Input signal to process.
+        comp : float or PyoObject, optional
+            Comparison value. If `input` is lower than this value,
+            `input` is send to the output, otherwise, `comp` is outputted.
+    
+    >>> s = Server().boot()
+    >>> s.start()
+    >>> # Triangle wave
+    >>> a = Phasor([249,250])
+    >>> b = Min(a, comp=a*-1+1, mul=4, add=-1)
+    >>> c = Tone(b, freq=1500, mul=.5).out()
+
+    """
+    def __init__(self, input, comp=0.5, mul=1, add=0):
+        PyoObject.__init__(self, mul, add)
+        self._input = input
+        self._comp = comp
+        self._in_fader = InputFader(input)
+        in_fader, comp, mul, add, lmax = convertArgsToLists(self._in_fader, comp, mul, add)
+        self._base_objs = [Min_base(wrap(in_fader,i), wrap(comp,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
+
+    def setInput(self, x, fadetime=0.05):
+        """
+        Replace the `input` attribute.
+        
+        :Args:
+
+            x : PyoObject
+                New signal to process.
+            fadetime : float, optional
+                Crossfade time between old and new input. Default to 0.05.
+
+        """
+        self._input = x
+        self._in_fader.setInput(x, fadetime)
+        
+    def setComp(self, x):
+        """
+        Replace the `comp` attribute.
+        
+        :Args:
+
+            x : float or PyoObject
+                New `comp` attribute.
+
+        """
+        self._comp = x
+        x, lmax = convertArgsToLists(x)
+        [obj.setComp(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
+
+    def ctrl(self, map_list=None, title=None, wxnoserver=False):
+        self._map_list = [SLMap(0,1,"lin", "comp", self._comp), SLMapMul(self._mul)]
+        PyoObject.ctrl(self, map_list, title, wxnoserver)
+      
+    @property
+    def input(self):
+        """PyoObject. Input signal to process.""" 
+        return self._input
+    @input.setter
+    def input(self, x): self.setInput(x)
+
+    @property
+    def comp(self):
+        """float or PyoObject. Comparison value.""" 
+        return self._comp
+    @comp.setter
+    def comp(self, x): self.setComp(x)
+
+class Max(PyoObject):
+    """
+    Outputs the maximum of two values.
+ 
+    :Parent: :py:class:`PyoObject`
+   
+    :Args:
+    
+        input : PyoObject
+            Input signal to process.
+        comp : float or PyoObject, optional
+            Comparison value. If `input` is higher than this value,
+            `input` is send to the output, otherwise, `comp` is outputted.
+    
+    >>> s = Server().boot()
+    >>> s.start()
+    >>> # Assimetrical clipping
+    >>> a = Phasor(500, mul=2, add=-1)
+    >>> b = Max(a, comp=-0.3)
+    >>> c = Tone(b, freq=1500, mul=.5).out()
+
+    """
+    def __init__(self, input, comp=0.5, mul=1, add=0):
+        PyoObject.__init__(self, mul, add)
+        self._input = input
+        self._comp = comp
+        self._in_fader = InputFader(input)
+        in_fader, comp, mul, add, lmax = convertArgsToLists(self._in_fader, comp, mul, add)
+        self._base_objs = [Max_base(wrap(in_fader,i), wrap(comp,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
+
+    def setInput(self, x, fadetime=0.05):
+        """
+        Replace the `input` attribute.
+        
+        :Args:
+
+            x : PyoObject
+                New signal to process.
+            fadetime : float, optional
+                Crossfade time between old and new input. Default to 0.05.
+
+        """
+        self._input = x
+        self._in_fader.setInput(x, fadetime)
+        
+    def setComp(self, x):
+        """
+        Replace the `comp` attribute.
+        
+        :Args:
+
+            x : float or PyoObject
+                New `comp` attribute.
+
+        """
+        self._comp = x
+        x, lmax = convertArgsToLists(x)
+        [obj.setComp(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
+
+    def ctrl(self, map_list=None, title=None, wxnoserver=False):
+        self._map_list = [SLMap(0,1,"lin", "comp", self._comp), SLMapMul(self._mul)]
+        PyoObject.ctrl(self, map_list, title, wxnoserver)
+      
+    @property
+    def input(self):
+        """PyoObject. Input signal to process.""" 
+        return self._input
+    @input.setter
+    def input(self, x): self.setInput(x)
+
+    @property
+    def comp(self):
+        """float or PyoObject. Comparison value.""" 
+        return self._comp
+    @comp.setter
+    def comp(self, x): self.setComp(x)
