@@ -34,54 +34,42 @@ class MatrixRec(PyoObject):
     """
     MatrixRec records samples into a previously created NewMatrix.
 
-    See `NewMatrix` to create an empty matrix.
+    See :py:class:`NewMatrix` to create an empty matrix.
 
     The play method is not called at the object creation time. It starts
     the recording into the matrix, row after row, until the matrix is full. 
     Calling the play method again restarts the recording and overwrites 
-    previously recorded samples.
+    previously recorded samples. The stop method stops the recording. 
+    Otherwise, the default behaviour is to record through the end of the matrix.
 
-    Parentclass: PyoObject
+    :Parent: :py:class:`PyoObject`
 
-    Parameters:
+    :Args:
 
-    input : PyoObject
-        Audio signal to write in the matrix.
-    matrix : PyoMatrixObject
-        The matrix where to write samples.
-    fadetime : float, optional
-        Fade time at the beginning and the end of the recording 
-        in seconds. Defaults to 0.
-    delay : int, optional
-        Delay time, in samples, before the recording begins. 
-        Available at initialization time only. Defaults to 0.
+        input : PyoObject
+            Audio signal to write in the matrix.
+        matrix : PyoMatrixObject
+            The matrix where to write samples.
+        fadetime : float, optional
+            Fade time at the beginning and the end of the recording 
+            in seconds. Defaults to 0.
+        delay : int, optional
+            Delay time, in samples, before the recording begins. 
+            Available at initialization time only. Defaults to 0.
 
-    Methods:
+    .. note::
 
-    setInput(x, fadetime) : Replace the `input` attribute.
-    setMatrix(x) : Replace the `matrix` attribute.
-    play() : Start the recording at the beginning of the matrix.
-    stop() : Stop the recording. Otherwise, record through the 
-        end of the matrix.
+        The out() method is bypassed. MatrixRec returns no signal.
 
-    Attributes:
+        MatrixRec has no `mul` and `add` attributes.
 
-    input : PyoObject. Audio signal to write in the matrix.
-    matrix : PyoMatrixObject. The matrix where to write samples.
+        MatrixRec will sends a trigger signal at the end of the recording. 
+        User can retreive the trigger streams by calling obj['trig']. See
+        `TableRec` documentation for an example.
 
-    Notes:
-
-    The out() method is bypassed. MatrixRec returns no signal.
-
-    MatrixRec has no `mul` and `add` attributes.
-
-    MatrixRec will sends a trigger signal at the end of the recording. 
-    User can retreive the trigger streams by calling obj['trig']. See
-    `TableRec` documentation for an example.
-
-    See also: NewMatrix
-
-    Examples:
+    .. seealso:: 
+        
+        :py:class:`NewMatrix`
 
     >>> s = Server().boot()
     >>> s.start()
@@ -107,9 +95,6 @@ class MatrixRec(PyoObject):
         self._base_objs = [MatrixRec_base(wrap(in_fader,i), wrap(matrix,i), wrap(fadetime,i), wrap(delay,i)) for i in range(len(matrix))]
         self._trig_objs = Dummy([TriggerDummy_base(obj) for obj in self._base_objs])
 
-    def __dir__(self):
-        return ['input', 'matrix']
-
     def out(self, chnl=0, inc=1, dur=0, delay=0):
         return self.play(dur, delay)
 
@@ -123,12 +108,12 @@ class MatrixRec(PyoObject):
         """
         Replace the `input` attribute.
         
-        Parameters:
+        :Args:
 
-        x : PyoObject
-            New signal to process.
-        fadetime : float, optional
-            Crossfade time between old and new input. Defaults to 0.05.
+            x : PyoObject
+                New signal to process.
+            fadetime : float, optional
+                Crossfade time between old and new input. Defaults to 0.05.
 
         """
         self._input = x
@@ -138,20 +123,16 @@ class MatrixRec(PyoObject):
         """
         Replace the `matrix` attribute.
         
-        Parameters:
+        :Args:
 
-        x : NewMatrix
-            new `matrix` attribute.
+            x : NewMatrix
+                new `matrix` attribute.
         
         """
         self._matrix = x
         x, lmax = convertArgsToLists(x)
         [obj.setMatrix(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
 
-    def ctrl(self, map_list=None, title=None, wxnoserver=False):
-        self._map_list = []
-        PyoObject.ctrl(self, map_list, title, wxnoserver)
-      
     @property
     def input(self):
         """PyoObject. Audio signal to record in the matrix.""" 
@@ -170,43 +151,33 @@ class MatrixRecLoop(PyoObject):
     """
     MatrixRecLoop records samples in loop into a previously created NewMatrix.
 
-    See `NewMatrix` to create an empty matrix.
+    See :py:class:`NewMatrix` to create an empty matrix.
 
     MatrixRecLoop records samples into the matrix, row after row, until 
     the matrix is full and then loop back to the beginning. 
 
-    Parentclass: PyoObject
+    :Parent: :py:class:`PyoObject`
 
-    Parameters:
+    :Args:
 
-    input : PyoObject
-        Audio signal to write in the matrix.
-    matrix : PyoMatrixObject
-        The matrix where to write samples.
+        input : PyoObject
+            Audio signal to write in the matrix.
+        matrix : PyoMatrixObject
+            The matrix where to write samples.
 
-    Methods:
+    .. note::
 
-    setInput(x, fadetime) : Replace the `input` attribute.
-    setMatrix(x) : Replace the `matrix` attribute.
+        The out() method is bypassed. MatrixRecLoop returns no signal.
 
-    Attributes:
+        MatrixRecLoop has no `mul` and `add` attributes.
 
-    input : PyoObject. Audio signal to write in the matrix.
-    matrix : PyoMatrixObject. The matrix where to write samples.
+        MatrixRecLoop will sends a trigger signal when reaching the end 
+        of the matrix. User can retreive the trigger streams by calling 
+        obj['trig']. See `TableRec` documentation for an example.
 
-    Notes:
-
-    The out() method is bypassed. MatrixRecLoop returns no signal.
-
-    MatrixRecLoop has no `mul` and `add` attributes.
-
-    MatrixRecLoop will sends a trigger signal when reaching the end 
-    of the matrix. User can retreive the trigger streams by calling 
-    obj['trig']. See `TableRec` documentation for an example.
-
-    See also: NewMatrix
-
-    Examples:
+    .. seealso:: 
+        
+        :py:class:`NewMatrix`
 
     >>> s = Server().boot()
     >>> s.start()
@@ -231,9 +202,6 @@ class MatrixRecLoop(PyoObject):
         self._base_objs = [MatrixRecLoop_base(wrap(in_fader,i), wrap(matrix,i)) for i in range(len(matrix))]
         self._trig_objs = Dummy([TriggerDummy_base(obj) for obj in self._base_objs])
 
-    def __dir__(self):
-        return ['input', 'matrix']
-
     def out(self, chnl=0, inc=1, dur=0, delay=0):
         return self.play(dur, delay)
 
@@ -247,12 +215,12 @@ class MatrixRecLoop(PyoObject):
         """
         Replace the `input` attribute.
 
-        Parameters:
+        :Args:
 
-        x : PyoObject
-            New signal to process.
-        fadetime : float, optional
-            Crossfade time between old and new input. Defaults to 0.05.
+            x : PyoObject
+                New signal to process.
+            fadetime : float, optional
+                Crossfade time between old and new input. Defaults to 0.05.
 
         """
         self._input = x
@@ -262,20 +230,16 @@ class MatrixRecLoop(PyoObject):
         """
         Replace the `matrix` attribute.
 
-        Parameters:
+        :Args:
 
-        x : NewMatrix
-            new `matrix` attribute.
+            x : NewMatrix
+                new `matrix` attribute.
 
         """
         self._matrix = x
         x, lmax = convertArgsToLists(x)
         [obj.setMatrix(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
 
-    def ctrl(self, map_list=None, title=None, wxnoserver=False):
-        self._map_list = []
-        PyoObject.ctrl(self, map_list, title, wxnoserver)
-
     @property
     def input(self):
         """PyoObject. Audio signal to record in the matrix.""" 
@@ -294,30 +258,16 @@ class MatrixPointer(PyoObject):
     """
     Matrix reader with control on the 2D pointer position.
 
-    Parentclass: PyoObject
+    :Parent: :py:class:`PyoObject`
 
-    Parameters:
+    :Args:
 
-    matrix : PyoMatrixObject
-        Matrix containing the waveform samples.
-    x : PyoObject
-        Normalized X position in the matrix between 0 and 1.
-    y : PyoObject
-        Normalized Y position in the matrix between 0 and 1.
-
-    Methods:
-
-    setMatrix(x) : Replace the `matrix` attribute.
-    setX(x) : Replace the `x` attribute.
-    setY(x) : Replace the `y` attribute
-
-    Attributes:
-
-    matrix : PyoMatrixObject. Matrix containing the waveform samples.
-    x : PyoObject. X pointer position in the matrix.
-    y : PyoObject. Y pointer position in the matrix.
-
-    Examples:
+        matrix : PyoMatrixObject
+            Matrix containing the waveform samples.
+        x : PyoObject
+            Normalized X position in the matrix between 0 and 1.
+        y : PyoObject
+            Normalized Y position in the matrix between 0 and 1.
 
     >>> s = Server().boot()
     >>> s.start()
@@ -335,26 +285,21 @@ class MatrixPointer(PyoObject):
 
     """
     def __init__(self, matrix, x, y, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._matrix = matrix
         self._x = x
         self._y = y
-        self._mul = mul
-        self._add = add
         matrix, x, y, mul, add, lmax = convertArgsToLists(matrix, x, y, mul, add)
         self._base_objs = [MatrixPointer_base(wrap(matrix,i), wrap(x,i), wrap(y,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['matrix', 'x', 'y', 'mul', 'add']
-
     def setMatrix(self, x):
         """
         Replace the `matrix` attribute.
         
-        Parameters:
+        :Args:
 
-        x : PyoTableObject
-            new `matrix` attribute.
+            x : PyoTableObject
+                new `matrix` attribute.
         
         """
         self._matrix = x
@@ -365,10 +310,10 @@ class MatrixPointer(PyoObject):
         """
         Replace the `x` attribute.
         
-        Parameters:
+        :Args:
 
-        x : PyoObject
-            new `x` attribute.
+            x : PyoObject
+                new `x` attribute.
         
         """
         self._x = x
@@ -379,10 +324,10 @@ class MatrixPointer(PyoObject):
         """
         Replace the `y` attribute.
         
-        Parameters:
+        :Args:
 
-        y : PyoObject
-            new `y` attribute.
+            y : PyoObject
+                new `y` attribute.
         
         """
         self._y = x
@@ -423,37 +368,23 @@ class MatrixMorph(PyoObject):
     `matrix` object at the beginning of each buffer size. The matrices in the 
     list and the resulting matrix must be equal in size.
 
-    Parentclass: PyoObject
+    :Parent: :py:class:`PyoObject`
 
-    Parameters:
+    :Args:
 
-    input : PyoObject
-        Morphing index between 0 and 1. 0 is the first matrix in the list 
-        and 1 is the last.
-    matrix : NewMatrix
-        The matrix where to write morphed function.
-    sources : list of PyoMatrixObject
-        List of matrices to interpolate from.
+        input : PyoObject
+            Morphing index between 0 and 1. 0 is the first matrix in the list 
+            and 1 is the last.
+        matrix : NewMatrix
+            The matrix where to write morphed function.
+        sources : list of PyoMatrixObject
+            List of matrices to interpolate from.
 
-    Methods:
+    .. note::
 
-    setInput(x, fadetime) : Replace the `input` attribute.
-    setMatrix(x) : Replace the `matrix` attribute.
-    setSources(x) : Replace the `sources` attribute.
+        The out() method is bypassed. MatrixMorph returns no signal.
 
-    Attributes:
-
-    input : PyoObject. Morphing index between 0 and 1.
-    matrix : NewMatrix. The matrix where to write samples.
-    sources : list of PyoMatrixObject. List of matrices to interpolate from.
-
-    Notes:
-
-    The out() method is bypassed. MatrixMorph returns no signal.
-
-    MatrixMorph has no `mul` and `add` attributes.
-
-    Examples:
+        MatrixMorph has no `mul` and `add` attributes.
 
     >>> s = Server().boot()
     >>> s.start()
@@ -479,9 +410,6 @@ class MatrixMorph(PyoObject):
         self._base_sources = [source[0] for source in sources]
         self._base_objs = [MatrixMorph_base(wrap(in_fader,i), wrap(matrix,i), self._base_sources) for i in range(len(matrix))]
 
-    def __dir__(self):
-        return ['input', 'matrix', 'sources', 'mul', 'add']
-
     def out(self, chnl=0, inc=1, dur=0, delay=0):
         return self.play(dur, delay)
 
@@ -495,12 +423,12 @@ class MatrixMorph(PyoObject):
         """
         Replace the `input` attribute.
 
-        Parameters:
+        :Args:
 
-        x : PyoObject
-            New signal to process.
-        fadetime : float, optional
-            Crossfade time between old and new input. Defaults to 0.05.
+            x : PyoObject
+                New signal to process.
+            fadetime : float, optional
+                Crossfade time between old and new input. Defaults to 0.05.
 
         """
         self._input = x
@@ -510,10 +438,10 @@ class MatrixMorph(PyoObject):
         """
         Replace the `matrix` attribute.
 
-        Parameters:
+        :Args:
 
-        x : NewMatrix
-            new `matrix` attribute.
+            x : NewMatrix
+                new `matrix` attribute.
 
         """
         self._matrix = x
@@ -524,20 +452,16 @@ class MatrixMorph(PyoObject):
         """
          Replace the `sources` attribute.
 
-        Parameters:
+        :Args:
 
-        x : list of PyoMatrixObject
-            new `sources` attribute.
+            x : list of PyoMatrixObject
+                new `sources` attribute.
 
         """
         self._sources = x
         self._base_sources = [source[0] for source in x]
         [obj.setSources(self._base_sources) for i, obj in enumerate(self._base_objs)]
 
-    def ctrl(self, map_list=None, title=None, wxnoserver=False):
-        self._map_list = []
-        PyoObject.ctrl(self, map_list, title, wxnoserver)
-
     @property
     def input(self):
         """PyoObject. Morphing index between 0 and 1.""" 
