@@ -23,7 +23,7 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with pyo.  If not, see <http://www.gnu.org/licenses/>.
 """
-import sys
+import sys, random
 from _core import *
 from _maps import *
 from types import SliceType, IntType
@@ -32,35 +32,20 @@ class Pan(PyoObject):
     """
     Cosinus panner with control on the spread factor.
 
-    Parentclass: PyoObject
+    :Parent: :py:class:`PyoObject`
 
-    Parameters:
+    :Args:
 
-    input : PyoObject
-        Input signal to process.
-    outs : int, optional
-        Number of channels on the panning circle. Defaults to 2.
-    pan : float or PyoObject
-        Position of the sound on the panning circle, between 0 and 1. 
-        Defaults to 0.5.
-    spread : float or PyoObject
-        Amount of sound leaking to the surrounding channels, 
-        between 0 and 1. Defaults to 0.5.
- 
-    Methods:
-
-    setInput(x, fadetime) : Replace the `input` attribute.
-    setPan(x) : Replace the `pan` attribute.
-    setSpread(x) : Replace the `spread` attribute.
-
-    Attributes:
-
-    input : PyoObject. Input signal to process.
-    pan : float or PyoObject. Position of the sound on the panning circle.
-    spread : float or PyoObject. Amount of sound leaking to the 
-        surrounding channels.
-
-    Examples:
+        input : PyoObject
+            Input signal to process.
+        outs : int, optional
+            Number of channels on the panning circle. Defaults to 2.
+        pan : float or PyoObject
+            Position of the sound on the panning circle, between 0 and 1. 
+            Defaults to 0.5.
+        spread : float or PyoObject
+            Amount of sound leaking to the surrounding channels, 
+            between 0 and 1. Defaults to 0.5.
 
     >>> s = Server(nchnls=2).boot()
     >>> s.start()
@@ -70,13 +55,11 @@ class Pan(PyoObject):
     
     """ 
     def __init__(self, input, outs=2, pan=0.5, spread=0.5, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._pan = pan
         self._outs = outs
         self._spread = spread
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, pan, spread, mul, add, lmax = convertArgsToLists(self._in_fader, pan, spread, mul, add)
         self._base_players = [Panner_base(wrap(in_fader,i), outs, wrap(pan,i), wrap(spread,i)) for i in range(lmax)]
@@ -85,19 +68,16 @@ class Pan(PyoObject):
             for j in range(outs):
                 self._base_objs.append(Pan_base(wrap(self._base_players,i), j, wrap(mul,i), wrap(add,i)))
 
-    def __dir__(self):
-        return ['input', 'pan', 'spread', 'mul', 'add']
-
     def setInput(self, x, fadetime=0.05):
         """
         Replace the `input` attribute.
         
-        Parameters:
+        :Args:
 
-        x : PyoObject
-            New signal to process.
-        fadetime : float, optional
-            Crossfade time between old and new input. Default to 0.05.
+            x : PyoObject
+                New signal to process.
+            fadetime : float, optional
+                Crossfade time between old and new input. Default to 0.05.
 
         """
         self._input = x
@@ -107,10 +87,10 @@ class Pan(PyoObject):
         """
         Replace the `pan` attribute.
         
-        Parameters:
+        :Args:
 
-        x : float or PyoObject
-            new `pan` attribute.
+            x : float or PyoObject
+                new `pan` attribute.
         
         """
         self._pan = x
@@ -121,10 +101,10 @@ class Pan(PyoObject):
         """
         Replace the `spread` attribute.
         
-        Parameters:
+        :Args:
 
-        x : float or PyoObject
-            new `spread` attribute.
+            x : float or PyoObject
+                new `spread` attribute.
         
         """
         self._spread = x
@@ -162,29 +142,17 @@ class SPan(PyoObject):
     """
     Simple equal power panner.
 
-    Parentclass: PyoObject
+    :Parent: :py:class:`PyoObject`
 
-    Parameters:
+    :Args:
 
-    input : PyoObject
-        Input signal to process.
-    outs : int, optional
-        Number of channels on the panning circle. Defaults to 2.
-    pan : float or PyoObject
-        Position of the sound on the panning circle, between 0 and 1. 
-        Defaults to 0.5.
-
-    Methods:
-
-    setInput(x, fadetime) : Replace the `input` attribute.
-    setPan(x) : Replace the `pan` attribute.
-
-    Attributes:
-
-    input : PyoObject. Input signal to process.
-    pan : float or PyoObject. Position of the sound on the panning circle.
-
-    Examples:
+        input : PyoObject
+            Input signal to process.
+        outs : int, optional
+            Number of channels on the panning circle. Defaults to 2.
+        pan : float or PyoObject
+            Position of the sound on the panning circle, between 0 and 1. 
+            Defaults to 0.5.
 
     >>> s = Server(nchnls=2).boot()
     >>> s.start()
@@ -194,12 +162,10 @@ class SPan(PyoObject):
 
     """
     def __init__(self, input, outs=2, pan=0.5, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._outs = outs
         self._pan = pan
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, pan, mul, add, lmax = convertArgsToLists(self._in_fader, pan, mul, add)
         self._base_players = [SPanner_base(wrap(in_fader,i), outs, wrap(pan,i)) for i in range(lmax)]
@@ -208,19 +174,16 @@ class SPan(PyoObject):
             for j in range(outs):
                 self._base_objs.append(SPan_base(wrap(self._base_players,i), j, wrap(mul,i), wrap(add,i)))
 
-    def __dir__(self):
-        return ['input', 'pan', 'mul', 'add']
-
     def setInput(self, x, fadetime=0.05):
         """
         Replace the `input` attribute.
         
-        Parameters:
+        :Args:
 
-        x : PyoObject
-            New signal to process.
-        fadetime : float, optional
-            Crossfade time between old and new input. Default to 0.05.
+            x : PyoObject
+                New signal to process.
+            fadetime : float, optional
+                Crossfade time between old and new input. Default to 0.05.
 
         """
         self._input = x
@@ -230,10 +193,10 @@ class SPan(PyoObject):
         """
         Replace the `pan` attribute.
         
-        Parameters:
+        :Args:
 
-        x : float or PyoObject
-            new `pan` attribute.
+            x : float or PyoObject
+                new `pan` attribute.
         
         """
         self._pan = x
@@ -268,29 +231,17 @@ class Switch(PyoObject):
     between brackets. obj[0] retrieve the first stream, obj[outs-1] the
     last one.
 
-    Parentclass: PyoObject
+    :Parent: :py:class:`PyoObject`
 
-    Parameters:
+    :Args:
 
-    input : PyoObject
-        Input signal to process.
-    outs : int, optional
-        Number of outputs. Defaults to 2.
-    voice : float or PyoObject
-        Voice position pointer, between 0 and (outs-1) / len(input). 
-        Defaults to 0.
-
-    Methods:
-
-    setInput(x, fadetime) : Replace the `input` attribute.
-    setVoice(x) : Replace the `voice` attribute.
-
-    Attributes:
-
-    input : PyoObject. Input signal to process.
-    voice : float or PyoObject. Voice position pointer.
-
-    Examples:
+        input : PyoObject
+            Input signal to process.
+        outs : int, optional
+            Number of outputs. Defaults to 2.
+        voice : float or PyoObject
+            Voice position pointer, between 0 and (outs-1) / len(input). 
+            Defaults to 0.
 
     >>> s = Server(nchnls=2).boot()
     >>> s.start()
@@ -303,12 +254,10 @@ class Switch(PyoObject):
 
     """
     def __init__(self, input, outs=2, voice=0., mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._outs = outs
         self._voice = voice
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, voice, mul, add, lmax = convertArgsToLists(self._in_fader, voice, mul, add)
         self._base_players = [Switcher_base(wrap(in_fader,i), outs, wrap(voice,i)) for i in range(lmax)]
@@ -317,19 +266,16 @@ class Switch(PyoObject):
             for i in range(lmax):
                 self._base_objs.append(Switch_base(wrap(self._base_players,i), j, wrap(mul,i), wrap(add,i)))
 
-    def __dir__(self):
-        return ['input', 'voice', 'mul', 'add']
-
     def setInput(self, x, fadetime=0.05):
         """
         Replace the `input` attribute.
 
-        Parameters:
+        :Args:
 
-        x : PyoObject
-            New signal to process.
-        fadetime : float, optional
-            Crossfade time between old and new input. Default to 0.05.
+            x : PyoObject
+                New signal to process.
+            fadetime : float, optional
+                Crossfade time between old and new input. Default to 0.05.
 
         """
         self._input = x
@@ -339,10 +285,10 @@ class Switch(PyoObject):
         """
         Replace the `voice` attribute.
 
-        Parameters:
+        :Args:
 
-        x : float or PyoObject
-            new `voice` attribute.
+            x : float or PyoObject
+                new `voice` attribute.
 
         """
         self._voice = x
@@ -374,27 +320,15 @@ class Selector(PyoObject):
     Selector takes multiple PyoObjects in input and interpolates between 
     them to generate a single output.
 
-    Parentclass: PyoObject
+    :Parent: :py:class:`PyoObject`
 
-    Parameters:
+    :Args:
 
-    inputs : list of PyoObject
-        Audio objects to interpolate from.
-    voice : float or PyoObject, optional
-        Voice position pointer, between 0 and len(inputs)-1. 
-        Defaults to 0.
-
-    Methods:
-
-    setInputs(x) : Replace the `inputs` attribute.
-    setVoice(x) : Replace the `voice` attribute.
-
-    Attributes:
-
-    inputs : list of PyoObject. Audio objects to interpolate from.
-    voice : float or PyoObject. Voice position pointer.
-
-    Examples:
+        inputs : list of PyoObject
+            Audio objects to interpolate from.
+        voice : float or PyoObject, optional
+            Voice position pointer, between 0 and len(inputs)-1. 
+            Defaults to 0.
 
     >>> s = Server().boot()
     >>> s.start()
@@ -406,11 +340,9 @@ class Selector(PyoObject):
 
     """
     def __init__(self, inputs, voice=0., mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._inputs = inputs
         self._voice = voice
-        self._mul = mul
-        self._add = add
         voice, mul, add, self._lmax = convertArgsToLists(voice, mul, add)
         self._length = 1
         for obj in self._inputs:
@@ -429,17 +361,14 @@ class Selector(PyoObject):
                         choice.append(obj)            
                 self._base_objs.append(Selector_base(choice, wrap(voice,i), wrap(mul,i), wrap(add,i)))
 
-    def __dir__(self):
-        return ['inputs', 'voice', 'mul', 'add']
-
     def setInputs(self, x):
         """
         Replace the `inputs` attribute.
         
-        Parameters:
+        :Args:
 
-        x : list of PyoObject
-            new `inputs` attribute.
+            x : list of PyoObject
+                new `inputs` attribute.
         
         """
         self._inputs = x
@@ -457,10 +386,10 @@ class Selector(PyoObject):
         """
         Replace the `voice` attribute.
         
-        Parameters:
+        :Args:
 
-        x : float or PyoObject
-            new `voice` attribute.
+            x : float or PyoObject
+                new `voice` attribute.
         
         """
         self._voice = x
@@ -473,13 +402,19 @@ class Selector(PyoObject):
         PyoObject.ctrl(self, map_list, title, wxnoserver)
 
     @property
-    def inputs(self): return self._inputs
+    def inputs(self): 
+        """List of PyoObjects. Audio objects to interpolate from."""
+        return self._inputs
     @inputs.setter
-    def inputs(self, x): self.setInputs(x)
+    def inputs(self, x): 
+        self.setInputs(x)
     @property
-    def voice(self): return self._voice
+    def voice(self): 
+        """float or PyoObject. Voice position pointer."""
+        return self._voice
     @voice.setter
-    def voice(self, x): self.setVoice(x)
+    def voice(self, x): 
+        self.setVoice(x)
 
 class VoiceManager(PyoObject):
     """
@@ -497,28 +432,17 @@ class VoiceManager(PyoObject):
 
     If there is no free voice, the object outputs -1.0 continuously.
 
-    Parentclass: PyoObject
+    :Parent: :py:class:`PyoObject`
 
-    Parameters:
+    :Args:
 
-    input : PyoObject
-        Trigger stream asking for new voice numbers.
-    triggers : PyoObject or list of PyoObject, optional
-        List of mono PyoObject sending triggers. Can be a multi-streams
-        PyoObject but not a mix of both. Ordering in the list corresponds
-        to voice numbers. Defaults to None.
-
-    Methods:
-
-    setInput(x, fadetime) : Replace the `input` attribute.
-    setTriggers(x) : Replace the `triggers` attribute.
-
-    Attributes:
-
-    input : PyoObject. Trigger stream asking for new voice numbers.
-    triggers : list of PyoObject. Trigger streams enabling voices.
-
-    Examples:
+        input : PyoObject
+            Trigger stream asking for new voice numbers.
+        triggers : PyoObject or list of PyoObject, optional
+            List of mono PyoObject sending triggers. Can be a multi-streams
+            PyoObject but not a mix of both. 
+            
+            Ordering in the list corresponds to voice numbers. Defaults to None.
 
     >>> s = Server().boot()
     >>> s.start()
@@ -533,11 +457,9 @@ class VoiceManager(PyoObject):
     
     """
     def __init__(self, input, triggers=None, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         self._input = input
         self._triggers = triggers
-        self._mul = mul
-        self._add = add
         self._in_fader = InputFader(input)
         in_fader, mul, add, lmax = convertArgsToLists(self._in_fader, mul, add)
         if triggers != None:
@@ -554,19 +476,16 @@ class VoiceManager(PyoObject):
             t_streams = None
         self._base_objs = [VoiceManager_base(wrap(in_fader,i), t_streams, wrap(mul,i), wrap(add,i)) for i in range(lmax)]
 
-    def __dir__(self):
-        return ['input', 'triggers', 'mul', 'add']
-
     def setInput(self, x, fadetime=0.05):
         """
         Replace the `input` attribute.
         
-        Parameters:
+        :Args:
 
-        x : PyoObject
-            New signal to process.
-        fadetime : float, optional
-            Crossfade time between old and new input. Defaults to 0.05.
+            x : PyoObject
+                New signal to process.
+            fadetime : float, optional
+                Crossfade time between old and new input. Defaults to 0.05.
 
         """
         self._input = x
@@ -576,10 +495,10 @@ class VoiceManager(PyoObject):
         """
         Replace the `triggers` attribute.
         
-        Parameters:
+        :Args:
 
-        x : PyoObject or list of PyoObject 
-            New `triggers` attribute.
+            x : PyoObject or list of PyoObject 
+                New `triggers` attribute.
 
         """
         self._triggers = x
@@ -595,20 +514,20 @@ class VoiceManager(PyoObject):
                 t_streams = None
         [obj.setTriggers(t_streams) for i, obj in enumerate(self._base_objs)]
 
-    def ctrl(self, map_list=None, title=None, wxnoserver=False):
-        self._map_list = []
-        PyoObject.ctrl(self, map_list, title, wxnoserver)
-
     @property
     def input(self):
         """PyoObject. Trigger stream asking for new voice numbers.""" 
         return self._input
     @input.setter
-    def input(self, x): self.setInput(x)
+    def input(self, x): 
+        self.setInput(x)
     @property
-    def triggers(self): return self._triggers
+    def triggers(self): 
+        """list of PyoObject. Trigger streams enabling voices."""
+        return self._triggers
     @triggers.setter
-    def triggers(self, x): self.setTriggers(x)
+    def triggers(self, x): 
+        self.setTriggers(x)
 
 class Mixer(PyoObject):
     """
@@ -618,38 +537,25 @@ class Mixer(PyoObject):
     with independant amplitude values per mixing channel and a 
     user defined portamento applied on amplitude changes.
 
-    Parentclass: PyoObject
+    :Parent: :py:class:`PyoObject`
 
-    Parameters:
+    :Args:
 
-    outs : int, optional
-        Number of outputs of the mixer. Available at initialization
-        time only. Defaults to 2.
-    chnls : int, optional
-        Number of channels per output. Available at initialization
-        time only. Defaults to 1.
-    time : float, optional
-        Duration, in seconds, of a portamento applied on
-        a new amplitude value for a mixing channel.
-        Defaults to 0.025.
+        outs : int, optional
+            Number of outputs of the mixer. Available at initialization
+            time only. Defaults to 2.
+        chnls : int, optional
+            Number of channels per output. Available at initialization
+            time only. Defaults to 1.
+        time : float, optional
+            Duration, in seconds, of a portamento applied on
+            a new amplitude value for a mixing channel.
+            Defaults to 0.025.
 
-    Methods:
+    .. note::
 
-    setTime(x) : Sets the portamento duration in seconds.
-    addInput(voice, input) : Adds a new input to the mixer.
-    delInput(voice) : Removes an input from the mixer.
-    setAmp(vin, vout, amp) : Sets the amplitude of a mixing channel.
-
-    Attributes:
-
-    time : float. Portamento applied on amplitude changes.
-
-    Notes:
-
-    User can retrieve each of the output channels by calling the Mixer
-    object with the desired channel between square brackets (see example).
-
-    Examples:
+        User can retrieve each of the output channels by calling the Mixer
+        object with the desired channel between square brackets (see example).
 
     >>> s = Server().boot()
     >>> s.start()
@@ -668,7 +574,7 @@ class Mixer(PyoObject):
 
     """
     def __init__(self, outs=2, chnls=1, time=0.025, mul=1, add=0):
-        PyoObject.__init__(self)
+        PyoObject.__init__(self, mul, add)
         if type(outs) != IntType:
             print >> sys.stderr, 'TypeError: "outs" argument of %s must be an integer.\n' % self.__class__.__name__
             exit()
@@ -678,16 +584,11 @@ class Mixer(PyoObject):
         self._outs = outs
         self._chnls = chnls
         self._time = time
-        self._mul = mul
-        self._add = add
         self._inputs = {}
         time, mul, add, lmax = convertArgsToLists(time, mul, add)
         self._base_players = [Mixer_base(outs, wrap(time,i)) for i in range(chnls)]
         self._base_objs = [MixerVoice_base(self._base_players[j], i, wrap(mul,i), wrap(add,i)) for i in range(outs) for j in range(chnls)]
         
-    def __dir__(self):
-        return ["time", "mul", "add"]
-
     def __getitem__(self, x):
         if type(x) == SliceType:
             return [self._base_objs[j*self._chnls+i] for j in range(x.start or 0, x.stop or sys.maxint, x.step or 1) for i in range(self._chnls)]
@@ -700,10 +601,10 @@ class Mixer(PyoObject):
         """
         Sets the portamento duration in seconds.
 
-        Parameters:
+        :Args:
 
-        x : float
-            New portamento duration.
+            x : float
+                New portamento duration.
 
         """
         self._time = x
@@ -714,25 +615,37 @@ class Mixer(PyoObject):
         """
         Adds an audio object in the mixer's inputs.
 
-        Parameters:
+        This method returns the key (voice argument or generated key if voice=None).
 
-        voice : int or string
-            Key in the mixer dictionary for this input.
-        input : PyoObject
-            Audio object to add to the mixer.
+        :Args:
+
+            voice : int or string
+                Key in the mixer dictionary for this input. If None, a unique key 
+                between 0 and 32767 will be automatically generated.
+            input : PyoObject
+                Audio object to add to the mixer.
 
         """
+        if voice == None:
+            voice = random.randint(0, 32767)
+            while self._inputs.has_key(voice):
+                voice = random.randint(0, 32767)
+        if self._inputs.has_key(voice):
+            print >> sys.stderr, "Mixer has already a key named %s" % voice
+            return
         self._inputs[voice] = input
+        input, lmax = convertArgsToLists(input)
         [obj.addInput(str(voice), wrap(input,i)) for i, obj in enumerate(self._base_players)]
+        return voice
 
     def delInput(self, voice):
         """
         Removes an audio object from the mixer's inputs.
 
-        Parameters:
+        :Args:
 
-        voice : int or string
-            Key in the mixer dictionary assigned to the input to remove.
+            voice : int or string
+                Key in the mixer dictionary assigned to the input to remove.
 
         """
         if self._inputs.has_key(voice):
@@ -743,19 +656,33 @@ class Mixer(PyoObject):
         """
         Sets the amplitude of a mixing channel.
 
-        Parameters:
+        :Args:
 
-        vin : int or string
-            Key in the mixer dictionary of the desired input.
-        vout : int
-            Ouput channel where to send the signal.
-        amp : float
-            Amplitude value for this mixing channel.
+            vin : int or string
+                Key in the mixer dictionary of the desired input.
+            vout : int
+                Ouput channel where to send the signal.
+            amp : float
+                Amplitude value for this mixing channel.
 
         """
         if self._inputs.has_key(vin) and vout < self._outs:
             [obj.setAmp(str(vin), vout, amp) for i, obj in enumerate(self._base_players)]
 
+    def getChannels(self):
+        """
+        Returns the Mixer's channels dictionary.
+        
+        """
+        return self._inputs
+
+    def getKeys(self):
+        """
+        Returns the list of current keys in the Mixer's channels dictionary.
+
+        """
+        return self._inputs.keys()
+        
     def ctrl(self, map_list=None, title=None, wxnoserver=False):
         self._map_list = [SLMapMul(self._mul)]
         PyoObject.ctrl(self, map_list, title, wxnoserver)
