@@ -16,6 +16,10 @@
  *                                                                        *
  * You should have received a copy of the GNU General Public License      *
  * along with pyo.  If not, see <http://www.gnu.org/licenses/>.           *
+ *                                                                        *
+ * Octobre 2013 : Multiple servers facility and embeded backend added by  *
+ * Guillaume Barrette. See embeded possibilities at:                      *
+ * https://github.com/guibarrette/PyoPlug                                 *
  *************************************************************************/
 
 #include <Python.h>
@@ -35,7 +39,12 @@
 #include "pyomodule.h"
 #include "servermodule.h"
 
-static Server *my_server = NULL;
+
+#define MAX_NBR_SERVER 256
+
+static Server *my_server[MAX_NBR_SERVER];
+static int serverID = 0;
+
 static PyObject *Server_shut_down(Server *self);
 static PyObject *Server_stop(Server *self);
 static void Server_process_gui(Server *server);
@@ -155,7 +164,7 @@ pa_callback_interleaved( const void *inputBuffer, void *outputBuffer,
     Server *server = (Server *) arg;
 
     assert(framesPerBuffer == server->bufferSize);
-    int i;
+    int i, j, bufchnls, index1, index2;
     
     /* avoid unused variable warnings */
     (void) timeInfo;
@@ -167,14 +176,24 @@ pa_callback_interleaved( const void *inputBuffer, void *outputBuffer,
     
     if (server->duplex == 1) {
         float *in = (float *)inputBuffer;
-        for (i=0; i<server->bufferSize*server->nchnls; i++) {
-            server->input_buffer[i] = (MYFLT)in[i];
+        bufchnls = server->nchnls + server->input_offset;
+        for (i=0; i<server->bufferSize; i++) {
+            index1 = i * server->nchnls;
+            index2 = i * bufchnls + server->input_offset;
+            for (j=0; j<server->nchnls; j++) {
+                server->input_buffer[index1+j] = (MYFLT)in[index2+j];
+            }
         }
     }
 
     Server_process_buffers(server);
-    for (i=0; i<server->bufferSize*server->nchnls; i++) {
-        out[i] = (float) server->output_buffer[i];
+    bufchnls = server->nchnls + server->output_offset;
+    for (i=0; i<server->bufferSize; i++) {
+        index1 = i * server->nchnls;
+        index2 = i * bufchnls + server->output_offset;
+        for (j=0; j<server->nchnls; j++) {
+            out[index2+j] = (float) server->output_buffer[index1+j];
+        }
     }
     server->midi_count = 0;
     
@@ -213,7 +232,7 @@ pa_callback_nonInterleaved( const void *inputBuffer, void *outputBuffer,
         float **in = (float **)inputBuffer;
         for (i=0; i<server->bufferSize; i++) {
             for (j=0; j<server->nchnls; j++) {
-                server->input_buffer[(i*server->nchnls)+j] = (MYFLT)in[j][i];
+                server->input_buffer[(i*server->nchnls)+j] = (MYFLT)in[j+server->input_offset][i];
             }
         }
     }
@@ -221,7 +240,7 @@ pa_callback_nonInterleaved( const void *inputBuffer, void *outputBuffer,
     Server_process_buffers(server);
     for (i=0; i<server->bufferSize; i++) {
         for (j=0; j<server->nchnls; j++) {
-            out[j][i] = (float) server->output_buffer[(i*server->nchnls)+j];
+            out[j+server->output_offset][i] = (float) server->output_buffer[(i*server->nchnls)+j];
         }
     }
     server->midi_count = 0;
@@ -252,10 +271,10 @@ jack_callback (jack_nframes_t nframes, void *arg)
     }
     PyoJackBackendData *be_data = (PyoJackBackendData *) server->audio_be_data;
     for (i = 0; i < server->nchnls; i++) {
-        in_buffers[i] = jack_port_get_buffer (be_data->jack_in_ports[i], server->bufferSize);
+        in_buffers[i] = jack_port_get_buffer (be_data->jack_in_ports[i+server->input_offset], server->bufferSize);
     }
     for (i = 0; i < server->nchnls; i++) {
-        out_buffers[i] = jack_port_get_buffer (be_data->jack_out_ports[i], server->bufferSize);
+        out_buffers[i] = jack_port_get_buffer (be_data->jack_out_ports[i+server->output_offset], server->bufferSize);
         
     }
     /* jack audio data is not interleaved */
@@ -328,7 +347,7 @@ OSStatus coreaudio_input_callback(AudioDeviceID device, const AudioTimeStamp* in
     bufchnls = inputBuf->mNumberChannels;
     servchnls = server->nchnls < bufchnls ? server->nchnls : bufchnls;
     for (i=0; i<server->bufferSize; i++) {
-        off1chnls = i*bufchnls;
+        off1chnls = i*bufchnls+server->input_offset;
         off2chnls = i*servchnls;
         for (j=0; j<servchnls; j++) {
             server->input_buffer[off2chnls+j] = (MYFLT)bufdata[off1chnls+j];
@@ -359,7 +378,7 @@ OSStatus coreaudio_output_callback(AudioDeviceID device, const AudioTimeStamp* i
     servchnls = server->nchnls < bufchnls ? server->nchnls : bufchnls;
     float *bufdata = (float*)outputBuf->mData;
     for (i=0; i<server->bufferSize; i++) {
-        off1chnls = i*bufchnls;
+        off1chnls = i*bufchnls+server->output_offset;
         off2chnls = i*servchnls;
         for(j=0; j<servchnls; j++) {
             bufdata[off1chnls+j] = server->output_buffer[off2chnls+j];
@@ -473,7 +492,7 @@ Server_pa_init(Server *self)
     /* setup output and input streams */
     memset(&outputParameters, 0, sizeof(outputParameters));
     outputParameters.device = outDevice;
-    outputParameters.channelCount = self->nchnls;
+    outputParameters.channelCount = self->nchnls + self->output_offset;
     outputParameters.sampleFormat = sampleFormat;
     outputParameters.suggestedLatency = Pa_GetDeviceInfo( outputParameters.device )->defaultHighOutputLatency;
     outputParameters.hostApiSpecificStreamInfo = NULL;
@@ -481,7 +500,7 @@ Server_pa_init(Server *self)
     if (self->duplex == 1) {
         memset(&inputParameters, 0, sizeof(inputParameters));
         inputParameters.device = inDevice;
-        inputParameters.channelCount = self->nchnls;
+        inputParameters.channelCount = self->nchnls + self->input_offset;
         inputParameters.sampleFormat = sampleFormat;
         inputParameters.suggestedLatency = Pa_GetDeviceInfo( inputParameters.device )->defaultHighInputLatency ;
         inputParameters.hostApiSpecificStreamInfo = NULL;
@@ -489,9 +508,9 @@ Server_pa_init(Server *self)
 
     if (self->input == -1 && self->output == -1) {
         if (self->duplex == 1)
-            err = Pa_OpenDefaultStream(&be_data->stream, self->nchnls, self->nchnls, sampleFormat, self->samplingRate, self->bufferSize, streamCallback, (void *) self);
+            err = Pa_OpenDefaultStream(&be_data->stream, self->nchnls + self->input_offset, self->nchnls + self->output_offset, sampleFormat, self->samplingRate, self->bufferSize, streamCallback, (void *) self);
         else
-            err = Pa_OpenDefaultStream(&be_data->stream, 0, self->nchnls, sampleFormat, self->samplingRate, self->bufferSize, streamCallback, (void *) self);
+            err = Pa_OpenDefaultStream(&be_data->stream, 0, self->nchnls + self->output_offset, sampleFormat, self->samplingRate, self->bufferSize, streamCallback, (void *) self);
     }
     else {
         if (self->duplex == 1)
@@ -559,38 +578,42 @@ int
 Server_jack_autoconnect (Server *self)
 {
     const char **ports;
-    int ret = 0;
+    int i, ret = 0;
     PyoJackBackendData *be_data = (PyoJackBackendData *) self->audio_be_data;
-    if ((ports = jack_get_ports (be_data->jack_client, NULL, NULL, 
-        JackPortIsOutput)) == NULL) {
-        Server_error(self, "Jack: Cannot find any physical capture ports\n");
-        ret = -1;
-    }
-    int i=0;
-    while(ports[i]!=NULL && be_data->jack_in_ports[i] != NULL){
-        if (jack_connect (be_data->jack_client, ports[i], jack_port_name(be_data->jack_in_ports[i]))) {
-            Server_error(self, "Jack: cannot connect input ports\n");
+    
+    if (self->jackautoin) {
+        if ((ports = jack_get_ports (be_data->jack_client, NULL, NULL, JackPortIsOutput)) == NULL) {
+            Server_error(self, "Jack: Cannot find any physical capture ports\n");
             ret = -1;
         }
-        i++;
-    }
-    free (ports);
-    
-    if ((ports = jack_get_ports (be_data->jack_client, NULL, NULL, 
-        JackPortIsInput)) == NULL) {
-        Server_error(self, "Jack: Cannot find any physical playback ports\n");
-        ret = -1;
+
+        i=0;
+        while(ports[i]!=NULL && be_data->jack_in_ports[i] != NULL){
+            if (jack_connect (be_data->jack_client, ports[i], jack_port_name(be_data->jack_in_ports[i]))) {
+                Server_error(self, "Jack: cannot connect input ports\n");
+                ret = -1;
+            }
+            i++;
+        }
+        free (ports);
     }
     
-    i=0;
-    while(ports[i]!=NULL && be_data->jack_out_ports[i] != NULL){
-        if (jack_connect (be_data->jack_client, jack_port_name (be_data->jack_out_ports[i]), ports[i])) {
-            Server_error(self, "Jack: cannot connect output ports\n");
+    if (self->jackautoout) {
+        if ((ports = jack_get_ports (be_data->jack_client, NULL, NULL, JackPortIsInput)) == NULL) {
+            Server_error(self, "Jack: Cannot find any physical playback ports\n");
             ret = -1;
         }
-        i++;
+        
+        i=0;
+        while(ports[i]!=NULL && be_data->jack_out_ports[i] != NULL){
+            if (jack_connect (be_data->jack_client, jack_port_name (be_data->jack_out_ports[i]), ports[i])) {
+                Server_error(self, "Jack: cannot connect output ports\n");
+                ret = -1;
+            }
+            i++;
+        }
+        free (ports);
     }
-    free (ports);
     return ret;
 }
 
@@ -598,16 +621,21 @@ int
 Server_jack_init (Server *self)
 {   
     char client_name[32];
+    char name[16];
     const char *server_name = "server";
     jack_options_t options = JackNullOption;
     jack_status_t status;
     int sampleRate = 0;
     int bufferSize = 0;
+    int nchnls = 0;
+    int total_nchnls = 0;
+    int index = 0;
+    int ret = 0;
     assert(self->audio_be_data == NULL);
     PyoJackBackendData *be_data = (PyoJackBackendData *) malloc(sizeof(PyoJackBackendData *));
     self->audio_be_data = (void *) be_data;
-    be_data->jack_in_ports = (jack_port_t **) calloc(self->nchnls, sizeof(jack_port_t *));
-    be_data->jack_out_ports = (jack_port_t **) calloc(self->nchnls, sizeof(jack_port_t *));
+    be_data->jack_in_ports = (jack_port_t **) calloc(self->nchnls + self->input_offset, sizeof(jack_port_t *));
+    be_data->jack_out_ports = (jack_port_t **) calloc(self->nchnls + self->output_offset, sizeof(jack_port_t *));
     strncpy(client_name,self->serverName, 32);
     be_data->jack_client = jack_client_open (client_name, options, &status, server_name);
     if (be_data->jack_client == NULL) {
@@ -647,26 +675,34 @@ Server_jack_init (Server *self)
     else {
         Server_debug(self, "Jack engine buffer size: %" PRIu32 "\n", bufferSize);
     }
-    int nchnls = self->nchnls;
-    
+
+    nchnls = total_nchnls = self->nchnls + self->input_offset;
     while (nchnls-- > 0) {
-        char name[16];
-        int ret;
-        int index = self->nchnls - nchnls - 1;
+        index = total_nchnls - nchnls - 1;
         ret = sprintf(name, "input_%i", index + 1);
         if (ret > 0) {
             be_data->jack_in_ports[index]
             = jack_port_register (be_data->jack_client, name, 
                                   JACK_DEFAULT_AUDIO_TYPE, JackPortIsInput, 0);
         }
-        ret = sprintf(name, "output_%i", self->nchnls - nchnls);
+
+        if ((be_data->jack_in_ports[index] == NULL)) {
+            Server_error(self, "Jack: no more JACK input ports available\n");
+            return -1;
+        }
+    }
+
+    nchnls = total_nchnls = self->nchnls + self->output_offset;
+    while (nchnls-- > 0) {
+        index = total_nchnls - nchnls - 1;
+        ret = sprintf(name, "output_%i", index + 1);
         if (ret > 0) {
             be_data->jack_out_ports[index] 
             = jack_port_register (be_data->jack_client, name, 
                                   JACK_DEFAULT_AUDIO_TYPE, JackPortIsOutput, 0);
         }
-        if ((be_data->jack_in_ports[index] == NULL) || (be_data->jack_out_ports[index] == NULL)) {
-            Server_error(self, "Jack: no more JACK ports available\n");
+        if ((be_data->jack_out_ports[index] == NULL)) {
+            Server_error(self, "Jack: no more JACK output ports available\n");
             return -1;
         }
     }
@@ -700,6 +736,7 @@ Server_jack_start (Server *self)
         Server_shut_down(self);
         return -1;
     }
+    //if (self->jackauto)
     Server_jack_autoconnect(self);
     return 0;
 }
@@ -1139,6 +1176,93 @@ Server_offline_stop(Server *self)
     return 0;
 }
 
+/******* Embedded Server *******/
+int
+Server_embedded_init(Server *self)
+{
+    return 0;
+}
+
+int
+Server_embedded_deinit(Server *self)
+{
+    return 0;
+}
+
+/* interleaved embedded callback */
+int
+Server_embedded_i_start(Server *self)
+{
+    Server_process_buffers(self);
+    return 0;
+}
+
+// To be easier to call without depending on the Server structure
+int
+Server_embedded_i_startIdx(int idx)
+{
+    Server_embedded_i_start(my_server[idx]);
+    return 0;
+}
+
+/* non-interleaved embedded callback */
+int
+Server_embedded_ni_start(Server *self)
+{
+    int i, j;
+    Server_process_buffers(self);
+    float *out = (float *)calloc(self->bufferSize * self->nchnls, sizeof(float));
+    for (i=0; i<(self->bufferSize*self->nchnls); i++){
+        out[i] = self->output_buffer[i];
+    }
+
+    /* Non-Interleaved */
+    for (i=0; i<self->bufferSize; i++) {
+        for (j=0; j<=self->nchnls; j++) {
+            /* This could probably be more efficient (ob) */
+            self->output_buffer[i+(self->bufferSize*(j+1))-self->bufferSize] = out[(i*self->nchnls)+j];
+        }
+    }
+    
+    return 0;
+}
+
+int
+Server_embedded_ni_startIdx(int idx)
+{
+    Server_embedded_ni_start(my_server[idx]);
+    return 0;
+}
+
+void 
+*Server_embedded_thread(void *arg)
+{
+    Server *self;
+    self = (Server *)arg;
+    
+    Server_process_buffers(self);
+
+    return NULL;
+}
+
+int
+Server_embedded_nb_start(Server *self)
+{
+    pthread_t offthread;
+    pthread_create(&offthread, NULL, Server_embedded_thread, self);
+    return 0;
+}
+
+/* this stop function is not very useful since the processing is stopped at the end 
+of every processing callback, but function put to not break pyo */
+int
+Server_embedded_stop(Server *self)
+{
+    self->server_started = 0;
+    self->server_stopped = 1;
+    return 0;
+}
+
 /***************************************************/
 /*  Main Processing functions                      */
 
@@ -1287,7 +1411,7 @@ Server_process_time(Server *server)
 PyObject *
 PyServer_get_server()
 {
-    return (PyObject *)my_server;
+    return (PyObject *)my_server[serverID];
 }
 
 static PyObject *
@@ -1328,21 +1452,15 @@ Server_shut_down(Server *self)
         case PyoOfflineNB:
             ret = Server_offline_deinit(self);  
             break;         
+        case PyoEmbedded:
+            ret = Server_embedded_deinit(self);
+            break;    
     }
     self->server_booted = 0;
     if (ret < 0) {
         Server_error(self, "Error closing audio backend.\n");
     }
-    
-    if (self->withPortMidi == 1)
-        Pm_Close(self->in);
 
-    if (self->withPortMidiOut == 1)
-        Pm_Close(self->out);
-    
-    if (self->withPortMidi == 1 || self->withPortMidiOut == 1)
-        Pm_Terminate();
-    
     Py_INCREF(Py_None);
     return Py_None;
 }
@@ -1370,23 +1488,52 @@ Server_dealloc(Server* self)
     free(self->input_buffer);
     free(self->output_buffer);
     free(self->serverName);
-    my_server = NULL;
+    my_server[self->thisServerID] = NULL;
     self->ob_type->tp_free((PyObject*)self);
 }
 
 static PyObject *
 Server_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 {
-    if (PyServer_get_server() != NULL) {
-        Server_warning((Server *) PyServer_get_server(), "Warning: A Server is already created!\n"
-            "If you put this Server in a new variable, please delete it!\n");
-        return PyServer_get_server();
-    }    
+    /* Unused variables to allow the safety check of the embeded audio backend. */
+    double samplingRate = 44100.0;
+    int  nchnls = 2;
+    int  bufferSize = 256;
+    int  duplex = 0;
+    char *audioType = "portaudio";
+    char *serverName = "pyo";
+        
+    static char *kwlist[] = {"sr", "nchnls", "buffersize", "duplex", "audio", "jackname", NULL};
+    if (! PyArg_ParseTupleAndKeywords(args, kwds, "|diiiss", kwlist, 
+            &samplingRate, &nchnls, &bufferSize, &duplex, &audioType, &serverName))
+        Py_RETURN_FALSE;
+        
+    if (strcmp(audioType, "embedded") != 0)
+    {
+        if (PyServer_get_server() != NULL) {
+            Server_warning((Server *) PyServer_get_server(), "Warning: A Server is already created!\n"
+                "If you put this Server in a new variable, please delete it!\n");
+            return PyServer_get_server();
+        }
+    }
+
+    /* find the first free serverID */
+    for(serverID = 0; serverID < MAX_NBR_SERVER; serverID++){
+        if(my_server[serverID] == NULL){
+            break;
+        }
+    }
+    if(serverID == MAX_NBR_SERVER){
+        return PyString_FromString("You are already using the maximum number of server allowed!");
+    }
+
     Server *self;
     self = (Server *)type->tp_alloc(type, 0);
     self->server_booted = 0;
     self->audio_be_data = NULL;
     self->serverName = (char *) calloc(32, sizeof(char));
+    self->jackautoin = 1;
+    self->jackautoout = 1;
     self->samplingRate = 44100.0;
     self->nchnls = 2;
     self->record = 0;
@@ -1394,6 +1541,8 @@ Server_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     self->duplex = 0;
     self->input = -1;
     self->output = -1;
+    self->input_offset = 0;
+    self->output_offset = 0;
     self->midi_input = -1;
     self->midi_output = -1;
     self->amp = self->resetAmp = 1.;
@@ -1406,8 +1555,9 @@ Server_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     self->rectype = 0;
     self->startoffset = 0.0;
     self->globalSeed = 0;
-    Py_XDECREF(my_server);
-    my_server = (Server *)self;
+    self->thisServerID = serverID;
+    Py_XDECREF(my_server[serverID]);
+    my_server[serverID] = (Server *)self;
     return (PyObject *)self;
 }
 
@@ -1438,6 +1588,9 @@ Server_init(Server *self, PyObject *args, PyObject *kwds)
     else if (strcmp(audioType, "offline_nb") == 0) {
         self->audio_be_type = PyoOfflineNB;
     } 
+    else if (strcmp(audioType, "embedded") == 0) {
+        self->audio_be_type = PyoEmbedded;
+    }
     else {
         Server_warning(self, "Unknown audio type. Using Portaudio\n");
         self->audio_be_type = PyoPortaudio;
@@ -1461,7 +1614,39 @@ Server_setDefaultRecPath(Server *self, PyObject *args, PyObject *kwds)
     Py_INCREF(Py_None);
     return Py_None;
 }
-    
+
+static PyObject *
+Server_setInputOffset(Server *self, PyObject *arg)
+{
+    if (self->server_booted) {
+        Server_warning(self, "Can't change input offset for booted server.\n");
+        Py_INCREF(Py_None);
+        return Py_None;
+    }
+	if (arg != NULL) {
+        if (PyInt_Check(arg))
+            self->input_offset = PyInt_AsLong(arg);
+    }
+    Py_INCREF(Py_None);
+    return Py_None;
+}
+
+static PyObject *
+Server_setOutputOffset(Server *self, PyObject *arg)
+{
+    if (self->server_booted) {
+        Server_warning(self, "Can't change output offset for booted server.\n");
+        Py_INCREF(Py_None);
+        return Py_None;
+    }
+	if (arg != NULL) {
+        if (PyInt_Check(arg))
+            self->output_offset = PyInt_AsLong(arg);
+    }
+    Py_INCREF(Py_None);
+    return Py_None;
+}
+
 static PyObject *
 Server_setInputDevice(Server *self, PyObject *arg)
 {
@@ -1588,6 +1773,23 @@ Server_setDuplex(Server *self, PyObject *arg)
     return Py_None;
 }
 
+static PyObject *
+Server_setJackAuto(Server *self, PyObject *args)
+{
+    int in=1, out=1;
+    
+    if (! PyArg_ParseTuple(args, "ii", &in, &out)) {
+        Py_INCREF(Py_None);
+        return Py_None;
+    }
+
+    self->jackautoin = in;
+    self->jackautoout = out;
+
+    Py_INCREF(Py_None);
+    return Py_None;
+}
+
 static PyObject *
 Server_setGlobalSeed(Server *self, PyObject *arg)
 {
@@ -1840,9 +2042,9 @@ Server_pm_init(Server *self)
 
 
 static PyObject *
-Server_boot(Server *self)
+Server_boot(Server *self, PyObject *arg)
 {
-    int audioerr = 0, midierr = 0;
+    int audioerr = 0;
     int i;
     if (self->server_booted == 1) {
         Server_error(self, "Server already booted!\n");
@@ -1852,9 +2054,14 @@ Server_boot(Server *self)
     self->server_started = 0;
     self->stream_count = 0;
     self->elapsedSamples = 0;
-    
-    midierr = Server_pm_init(self);
-    Server_debug(self, "PortMidi initialization return code : %d.\n", midierr);
+
+    int needNewBuffer = 0;
+    if (arg != NULL && PyBool_Check(arg)) {
+        needNewBuffer = PyObject_IsTrue(arg);
+    }
+    else {
+        Server_error(self, "The argument to set for a new buffer must be a boolean.\n");
+    }
 
     self->streams = PyList_New(0);
     switch (self->audio_be_type) {
@@ -1895,21 +2102,108 @@ Server_boot(Server *self)
                 Server_offline_deinit(self);
             }
             break;
+        case PyoEmbedded:
+            audioerr = Server_embedded_init(self);
+            if (audioerr < 0) {
+                Server_embedded_deinit(self);
+            }
+            break;
     }
-    // Must allocate buffer after initializing the audio backend in case parameters change there
-    if (self->input_buffer) {
-        free(self->input_buffer);
+    if (needNewBuffer == 1){
+        /* Must allocate buffer after initializing the audio backend in case parameters change there */
+        if (self->input_buffer) {
+            free(self->input_buffer);
+        }
+        self->input_buffer = (MYFLT *)calloc(self->bufferSize * self->nchnls, sizeof(MYFLT));
+        if (self->output_buffer) {
+            free(self->output_buffer);
+        }
+        self->output_buffer = (float *)calloc(self->bufferSize * self->nchnls, sizeof(float));
     }
-    self->input_buffer = (MYFLT *)calloc(self->bufferSize * self->nchnls, sizeof(MYFLT));
-    if (self->output_buffer) {
-        free(self->output_buffer);
-    }
-    self->output_buffer = (float *)calloc(self->bufferSize * self->nchnls, sizeof(float));
     for (i=0; i<self->bufferSize*self->nchnls; i++) {
         self->input_buffer[i] = 0.0;
         self->output_buffer[i] = 0.0;
     }
-    if (audioerr == 0 && midierr == 0) {
+    if (audioerr == 0) {
+        self->server_booted = 1;
+    }
+    else {
+        self->server_booted = 0;
+        Server_error(self, "\nServer not booted.\n");
+    }    
+    
+    Py_INCREF(Py_None);
+    return Py_None;
+}
+
+/* Like the Server_boot() but without reinitializing the buffers */
+static PyObject *
+Server_flush(Server *self)
+{
+    int audioerr = 0;
+    int i;
+    if (self->server_booted == 1) {
+        Server_error(self, "Server already booted!\n");
+        Py_INCREF(Py_None);
+        return Py_None;
+    }
+    self->server_started = 0;
+    self->stream_count = 0;
+    self->elapsedSamples = 0;
+
+    self->streams = PyList_New(0);
+    switch (self->audio_be_type) {
+        case PyoPortaudio:
+            audioerr = Server_pa_init(self);
+            break;
+        case PyoJack:
+#ifdef USE_JACK
+            audioerr = Server_jack_init(self);
+            if (audioerr < 0) {
+                Server_jack_deinit(self);
+            }
+#else
+            audioerr = -1;
+            Server_error(self, "Pyo built without Jack support\n");
+#endif
+            break;
+        case PyoCoreaudio:
+#ifdef USE_COREAUDIO
+            audioerr = Server_coreaudio_init(self);
+            if (audioerr < 0) {
+                Server_coreaudio_deinit(self);
+            }
+#else
+            audioerr = -1;
+            Server_error(self, "Pyo built without Coreaudio support\n");
+#endif
+            break;
+        case PyoOffline:
+            audioerr = Server_offline_init(self);
+            if (audioerr < 0) {
+                Server_offline_deinit(self);
+            }
+            break;
+        case PyoOfflineNB:
+            audioerr = Server_offline_init(self);
+            if (audioerr < 0) {
+                Server_offline_deinit(self);
+            }
+            break;
+        case PyoEmbedded:
+            audioerr = Server_embedded_init(self);
+            if (audioerr < 0) {
+                Server_embedded_deinit(self);
+            }
+            break;
+    }
+
+    for (i=0; i<self->bufferSize*self->nchnls; i++) {
+        self->input_buffer[i] = 0.0;
+        self->output_buffer[i] = 0.0;
+    }
+    
+    if (audioerr == 0) {
         self->server_booted = 1;
     }
     else {
@@ -1924,6 +2218,7 @@ Server_boot(Server *self)
 static PyObject *
 Server_start(Server *self)
 {
+    int err = -1, midierr = 0;
     if (self->server_started == 1) {
         Server_warning(self, "Server already started!\n");
         Py_INCREF(Py_None);
@@ -1935,9 +2230,8 @@ Server_start(Server *self)
         Py_INCREF(Py_None);
         return Py_None;
     }
-    int err = -1;
     
-    Server_debug(self, "Number of streams %d\n", self->stream_count);
+    Server_debug(self, "Server_start: number of streams %d\n", self->stream_count);
 
     /* Ensure Python is set up for threading */
     PyEval_InitThreads();
@@ -1945,7 +2239,12 @@ Server_start(Server *self)
     self->server_stopped = 0;
     self->server_started = 1;
     self->timeStep = (int)(0.01 * self->samplingRate);
-    
+
+    if (self->audio_be_type != PyoOffline && self->audio_be_type != PyoOfflineNB) {
+        midierr = Server_pm_init(self);
+        Server_debug(self, "PortMidi initialization return code : %d.\n", midierr);
+    }
+
     if (self->startoffset > 0.0) {
         Server_message(self,"Rendering %.2f seconds offline...\n", self->startoffset);
         int numBlocks = ceil(self->startoffset * self->samplingRate/self->bufferSize);
@@ -1979,6 +2278,9 @@ Server_start(Server *self)
         case PyoOfflineNB:
             err = Server_offline_nb_start(self);
             break;           
+        case PyoEmbedded:
+            err = Server_embedded_nb_start(self);
+            break;
     }
     if (err) {
         Server_error(self, "Error starting server.\n");
@@ -2017,6 +2319,9 @@ Server_stop(Server *self)
         case PyoOfflineNB:
             err = Server_offline_stop(self);
             break;    
+        case PyoEmbedded:
+            err = Server_embedded_stop(self);
+            break;
     }
 
     if (err < 0) {
@@ -2024,6 +2329,17 @@ Server_stop(Server *self)
     }
     else {
         self->server_stopped = 1;
+        if (self->withPortMidi == 1) {
+            Pm_Close(self->in);
+        }
+        if (self->withPortMidiOut == 1) {
+            Pm_Close(self->out);
+        }
+        if (self->withPortMidi == 1 || self->withPortMidiOut == 1) {
+            Pm_Terminate();
+        }
+        self->withPortMidi = 0;
+        self->withPortMidiOut = 0;
     }
     Py_INCREF(Py_None);
     return Py_None;
@@ -2075,23 +2391,49 @@ Server_start_rec_internal(Server *self, char *filename)
         case 1:
             self->recinfo.format = SF_FORMAT_AIFF;
             break;
-    }
-    switch (self->rectype) {
-        case 0:
-            self->recinfo.format = self->recinfo.format | SF_FORMAT_PCM_16;
-            break;
-        case 1:
-            self->recinfo.format = self->recinfo.format | SF_FORMAT_PCM_24;
-            break;
         case 2:
-            self->recinfo.format = self->recinfo.format | SF_FORMAT_PCM_32;
+            self->recinfo.format = SF_FORMAT_AU;
             break;
         case 3:
-            self->recinfo.format = self->recinfo.format | SF_FORMAT_FLOAT;
+            self->recinfo.format = SF_FORMAT_RAW;
             break;
         case 4:
-            self->recinfo.format = self->recinfo.format | SF_FORMAT_DOUBLE;
+            self->recinfo.format = SF_FORMAT_SD2;
             break;
+        case 5:
+            self->recinfo.format = SF_FORMAT_FLAC;
+            break;
+        case 6:
+            self->recinfo.format = SF_FORMAT_CAF;
+            break;
+        case 7:
+            self->recinfo.format = SF_FORMAT_OGG | SF_FORMAT_VORBIS;
+            break;
+    }
+    if (self->recformat != 7) {
+        switch (self->rectype) {
+            case 0:
+                self->recinfo.format = self->recinfo.format | SF_FORMAT_PCM_16;
+                break;
+            case 1:
+                self->recinfo.format = self->recinfo.format | SF_FORMAT_PCM_24;
+                break;
+            case 2:
+                self->recinfo.format = self->recinfo.format | SF_FORMAT_PCM_32;
+                break;
+            case 3:
+                self->recinfo.format = self->recinfo.format | SF_FORMAT_FLOAT;
+                break;
+            case 4:
+                self->recinfo.format = self->recinfo.format | SF_FORMAT_DOUBLE;
+                break;
+            case 5:
+                self->recinfo.format = self->recinfo.format | SF_FORMAT_ULAW;
+                break;
+            case 6:
+                self->recinfo.format = self->recinfo.format | SF_FORMAT_ALAW;
+                break;
+        }
     }
     Server_debug(self, "recinfo.format : %i\n", self->recinfo.format);
 
@@ -2293,10 +2635,75 @@ Server_getStreams(Server *self)
     return self->streams;
 }
 
+static PyObject *
+Server_setServer(Server *self)
+{
+    serverID = self->thisServerID;
+    /* Should return a more conventional signal, like True or False */
+    return PyString_FromString("Server set");
+}
+
+
+static PyObject *
+Server_getInputAddr(Server *self)
+{
+    char address[32];
+    sprintf(address, "%p", &self->input_buffer[0]);
+    return PyString_FromString(address);
+}
+
+
+static PyObject *
+Server_getOutputAddr(Server *self)
+{
+    char address[32];
+    sprintf(address, "%p", &self->output_buffer[0]);
+    return PyString_FromString(address);
+}
+
+static PyObject *
+Server_getServerID(Server *self)
+{
+    return PyInt_FromLong(self->thisServerID);
+}
+
+static PyObject *
+Server_getServerAddr(Server *self)
+{
+    char address[32];
+    sprintf(address, "%p", &my_server[self->thisServerID]);
+    return PyString_FromString(address);
+}
+
+void
+Server_getThisServer(int id, Server *server)
+{
+    server = my_server[id];
+}
+
+/*
+static PyObject *
+Server_getThisServerFunc(Server *self)
+{
+    char address[32];
+    sprintf(address, "%p", &Server_getThisServer);
+    return PyString_FromString(address);
+}
+*/
+
+static PyObject *
+Server_getEmbedICallbackAddr(Server *self)
+{
+    char address[32];
+    sprintf(address, "%p", &Server_embedded_i_startIdx);
+    return PyString_FromString(address);
+}
 
 static PyMethodDef Server_methods[] = {
     {"setInputDevice", (PyCFunction)Server_setInputDevice, METH_O, "Sets audio input device."},
     {"setOutputDevice", (PyCFunction)Server_setOutputDevice, METH_O, "Sets audio output device."},
+    {"setInputOffset", (PyCFunction)Server_setInputOffset, METH_O, "Sets audio input channel offset."},
+    {"setOutputOffset", (PyCFunction)Server_setOutputOffset, METH_O, "Sets audio output channel offset."},
     {"setInOutDevice", (PyCFunction)Server_setInOutDevice, METH_O, "Sets both audio input and output device."},
     {"setMidiInputDevice", (PyCFunction)Server_setMidiInputDevice, METH_O, "Sets MIDI input device."},
     {"setMidiOutputDevice", (PyCFunction)Server_setMidiOutputDevice, METH_O, "Sets MIDI output device."},
@@ -2304,13 +2711,14 @@ static PyMethodDef Server_methods[] = {
     {"setBufferSize", (PyCFunction)Server_setBufferSize, METH_O, "Sets the server's buffer size."},
     {"setNchnls", (PyCFunction)Server_setNchnls, METH_O, "Sets the server's number of channels."},
     {"setDuplex", (PyCFunction)Server_setDuplex, METH_O, "Sets the server's duplex mode (0 = only out, 1 = in/out)."},
+    {"setJackAuto", (PyCFunction)Server_setJackAuto, METH_VARARGS, "Tells the server to auto-connect Jack ports (0 = disable, 1 = enable)."},
     {"setGlobalSeed", (PyCFunction)Server_setGlobalSeed, METH_O, "Sets the server's global seed for random objects."},
     {"setAmp", (PyCFunction)Server_setAmp, METH_O, "Sets the overall amplitude."},
     {"setAmpCallable", (PyCFunction)Server_setAmpCallable, METH_O, "Sets the Server's GUI callable object."},
     {"setTimeCallable", (PyCFunction)Server_setTimeCallable, METH_O, "Sets the Server's TIME callable object."},
     {"setVerbosity", (PyCFunction)Server_setVerbosity, METH_O, "Sets the verbosity."},
     {"setStartOffset", (PyCFunction)Server_setStartOffset, METH_O, "Sets starting time offset."},
-    {"boot", (PyCFunction)Server_boot, METH_NOARGS, "Setup and boot the server."},
+    {"boot", (PyCFunction)Server_boot, METH_O, "Setup and boot the server."},
     {"shutdown", (PyCFunction)Server_shut_down, METH_NOARGS, "Shut down the server."},
     {"start", (PyCFunction)Server_start, METH_NOARGS, "Starts the server's callback loop."},
     {"stop", (PyCFunction)Server_stop, METH_NOARGS, "Stops the server's callback loop."},
@@ -2333,6 +2741,13 @@ static PyMethodDef Server_methods[] = {
     {"getIsStarted", (PyCFunction)Server_getIsStarted, METH_NOARGS, "Returns 1 if the server is started, otherwise returns 0."},
     {"getMidiActive", (PyCFunction)Server_getMidiActive, METH_NOARGS, "Returns 1 if midi callback is active, otherwise returns 0."},
     {"_setDefaultRecPath", (PyCFunction)Server_setDefaultRecPath, METH_VARARGS|METH_KEYWORDS, "Sets the default recording path."},
+    {"setServer", (PyCFunction)Server_setServer, METH_NOARGS, "Sets this server as the one to use for new objects when using the embedded device"},
+    {"flush", (PyCFunction)Server_flush, METH_NOARGS, "Flush the server objects"},
+    {"getInputAddr", (PyCFunction)Server_getInputAddr, METH_NOARGS, "Get the embedded device input buffer memory address"},
+    {"getOutputAddr", (PyCFunction)Server_getOutputAddr, METH_NOARGS, "Get the embedded device output buffer memory address"},
+    {"getServerID", (PyCFunction)Server_getServerID, METH_NOARGS, "Get the embedded device server memory address"},
+    {"getServerAddr", (PyCFunction)Server_getServerAddr, METH_NOARGS, "Get the embedded device server memory address"},
+    {"getEmbedICallbackAddr", (PyCFunction)Server_getEmbedICallbackAddr, METH_NOARGS, "Get the embedded device interleaved callback method memory address"},
     {NULL}  /* Sentinel */
 };
 
