@@ -24,6 +24,7 @@
 #include "streammodule.h"
 #include "servermodule.h"
 #include "dummymodule.h"
+#include "interpolation.h"
 
 /************/
 /* Follower */
@@ -170,17 +171,16 @@ Follower_clear(Follower *self)
 static void
 Follower_dealloc(Follower* self)
 {
-    free(self->data);
+    pyo_DEALLOC
     Follower_clear(self);
     self->ob_type->tp_free((PyObject*)self);
 }
 
-static PyObject * Follower_deleteStream(Follower *self) { DELETE_STREAM };
-
 static PyObject *
 Follower_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 {
     int i;
+    PyObject *inputtmp, *input_streamtmp, *freqtmp=NULL, *multmp=NULL, *addtmp=NULL;
     Follower *self;
     self = (Follower *)type->tp_alloc(type, 0);
     
@@ -195,18 +195,11 @@ Follower_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     INIT_OBJECT_COMMON
     Stream_setFunctionPtr(self->stream, Follower_compute_next_data_frame);
     self->mode_func_ptr = Follower_setProcMode;
-    return (PyObject *)self;
-}
 
-static int
-Follower_init(Follower *self, PyObject *args, PyObject *kwds)
-{
-    PyObject *inputtmp, *input_streamtmp, *freqtmp=NULL, *multmp=NULL, *addtmp=NULL;
-    
     static char *kwlist[] = {"input", "freq", "mul", "add", NULL};
     
     if (! PyArg_ParseTupleAndKeywords(args, kwds, "O|OOO", kwlist, &inputtmp, &freqtmp, &multmp, &addtmp))
-        return -1; 
+        Py_RETURN_NONE; 
     
     INIT_INPUT_STREAM
     
@@ -222,13 +215,11 @@ Follower_init(Follower *self, PyObject *args, PyObject *kwds)
         PyObject_CallMethod((PyObject *)self, "setAdd", "O", addtmp);
     }
     
-    Py_INCREF(self->stream);
     PyObject_CallMethod(self->server, "addStream", "O", self->stream);
     
     (*self->mode_func_ptr)(self);
-        
-    Py_INCREF(self);
-    return 0;
+
+    return (PyObject *)self;
 }
 
 static PyObject * Follower_getServer(Follower* self) { GET_SERVER };
@@ -297,7 +288,6 @@ static PyMemberDef Follower_members[] = {
 static PyMethodDef Follower_methods[] = {
 {"getServer", (PyCFunction)Follower_getServer, METH_NOARGS, "Returns server object."},
 {"_getStream", (PyCFunction)Follower_getStream, METH_NOARGS, "Returns stream object."},
-{"deleteStream", (PyCFunction)Follower_deleteStream, METH_NOARGS, "Remove stream from server and delete the object."},
 {"play", (PyCFunction)Follower_play, METH_VARARGS|METH_KEYWORDS, "Starts computing without sending sound to soundcard."},
 {"stop", (PyCFunction)Follower_stop, METH_NOARGS, "Stops computing."},
 {"setFreq", (PyCFunction)Follower_setFreq, METH_O, "Sets filter cutoff frequency in cycle per second."},
@@ -387,7 +377,7 @@ Follower_members,                                 /* tp_members */
 0,                                              /* tp_descr_get */
 0,                                              /* tp_descr_set */
 0,                                              /* tp_dictoffset */
-(initproc)Follower_init,                          /* tp_init */
+0,                          /* tp_init */
 0,                                              /* tp_alloc */
 Follower_new,                                     /* tp_new */
 };
@@ -645,17 +635,16 @@ Follower2_clear(Follower2 *self)
 static void
 Follower2_dealloc(Follower2* self)
 {
-    free(self->data);
+    pyo_DEALLOC
     Follower2_clear(self);
     self->ob_type->tp_free((PyObject*)self);
 }
 
-static PyObject * Follower2_deleteStream(Follower2 *self) { DELETE_STREAM };
-
 static PyObject *
 Follower2_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 {
     int i;
+    PyObject *inputtmp, *input_streamtmp, *risetimetmp=NULL, *falltimetmp=NULL, *multmp=NULL, *addtmp=NULL;
     Follower2 *self;
     self = (Follower2 *)type->tp_alloc(type, 0);
     
@@ -673,18 +662,11 @@ Follower2_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     INIT_OBJECT_COMMON
     Stream_setFunctionPtr(self->stream, Follower2_compute_next_data_frame);
     self->mode_func_ptr = Follower2_setProcMode;
-    return (PyObject *)self;
-}
 
-static int
-Follower2_init(Follower2 *self, PyObject *args, PyObject *kwds)
-{
-    PyObject *inputtmp, *input_streamtmp, *risetimetmp=NULL, *falltimetmp=NULL, *multmp=NULL, *addtmp=NULL;
-    
     static char *kwlist[] = {"input", "risetime", "falltime", "mul", "add", NULL};
     
     if (! PyArg_ParseTupleAndKeywords(args, kwds, "O|OOOO", kwlist, &inputtmp, &risetimetmp, &falltimetmp, &multmp, &addtmp))
-        return -1; 
+        Py_RETURN_NONE; 
     
     INIT_INPUT_STREAM
     
@@ -704,13 +686,11 @@ Follower2_init(Follower2 *self, PyObject *args, PyObject *kwds)
         PyObject_CallMethod((PyObject *)self, "setAdd", "O", addtmp);
     }
     
-    Py_INCREF(self->stream);
     PyObject_CallMethod(self->server, "addStream", "O", self->stream);
     
     (*self->mode_func_ptr)(self);
-    
-    Py_INCREF(self);
-    return 0;
+
+    return (PyObject *)self;
 }
 
 static PyObject * Follower2_getServer(Follower2* self) { GET_SERVER };
@@ -814,7 +794,6 @@ static PyMemberDef Follower2_members[] = {
 static PyMethodDef Follower2_methods[] = {
     {"getServer", (PyCFunction)Follower2_getServer, METH_NOARGS, "Returns server object."},
     {"_getStream", (PyCFunction)Follower2_getStream, METH_NOARGS, "Returns stream object."},
-    {"deleteStream", (PyCFunction)Follower2_deleteStream, METH_NOARGS, "Remove stream from server and delete the object."},
     {"play", (PyCFunction)Follower2_play, METH_VARARGS|METH_KEYWORDS, "Starts computing without sending sound to soundcard."},
     {"stop", (PyCFunction)Follower2_stop, METH_NOARGS, "Stops computing."},
     {"setRisetime", (PyCFunction)Follower2_setRisetime, METH_O, "Sets filter risetime in second."},
@@ -905,7 +884,7 @@ PyTypeObject Follower2Type = {
     0,                                              /* tp_descr_get */
     0,                                              /* tp_descr_set */
     0,                                              /* tp_dictoffset */
-    (initproc)Follower2_init,                          /* tp_init */
+    0,                          /* tp_init */
     0,                                              /* tp_alloc */
     Follower2_new,                                     /* tp_new */
 };
@@ -1023,17 +1002,16 @@ ZCross_clear(ZCross *self)
 static void
 ZCross_dealloc(ZCross* self)
 {
-    free(self->data);
+    pyo_DEALLOC
     ZCross_clear(self);
     self->ob_type->tp_free((PyObject*)self);
 }
 
-static PyObject * ZCross_deleteStream(ZCross *self) { DELETE_STREAM };
-
 static PyObject *
 ZCross_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 {
     int i;
+    PyObject *inputtmp, *input_streamtmp, *multmp=NULL, *addtmp=NULL;
     ZCross *self;
     self = (ZCross *)type->tp_alloc(type, 0);
     
@@ -1045,18 +1023,11 @@ ZCross_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     INIT_OBJECT_COMMON
     Stream_setFunctionPtr(self->stream, ZCross_compute_next_data_frame);
     self->mode_func_ptr = ZCross_setProcMode;
-    return (PyObject *)self;
-}
 
-static int
-ZCross_init(ZCross *self, PyObject *args, PyObject *kwds)
-{
-    PyObject *inputtmp, *input_streamtmp, *multmp=NULL, *addtmp=NULL;
-    
     static char *kwlist[] = {"input", "thresh", "mul", "add", NULL};
     
     if (! PyArg_ParseTupleAndKeywords(args, kwds, TYPE_O_FOO, kwlist, &inputtmp, &self->thresh, &multmp, &addtmp))
-        return -1; 
+        Py_RETURN_NONE; 
 
     INIT_INPUT_STREAM
     
@@ -1068,13 +1039,11 @@ ZCross_init(ZCross *self, PyObject *args, PyObject *kwds)
         PyObject_CallMethod((PyObject *)self, "setAdd", "O", addtmp);
     }
     
-    Py_INCREF(self->stream);
     PyObject_CallMethod(self->server, "addStream", "O", self->stream);
     
     (*self->mode_func_ptr)(self);
-        
-    Py_INCREF(self);
-    return 0;
+
+    return (PyObject *)self;
 }
 
 static PyObject * ZCross_getServer(ZCross* self) { GET_SERVER };
@@ -1126,7 +1095,6 @@ static PyMemberDef ZCross_members[] = {
 static PyMethodDef ZCross_methods[] = {
 {"getServer", (PyCFunction)ZCross_getServer, METH_NOARGS, "Returns server object."},
 {"_getStream", (PyCFunction)ZCross_getStream, METH_NOARGS, "Returns stream object."},
-{"deleteStream", (PyCFunction)ZCross_deleteStream, METH_NOARGS, "Remove stream from server and delete the object."},
 {"play", (PyCFunction)ZCross_play, METH_VARARGS|METH_KEYWORDS, "Starts computing without sending sound to soundcard."},
 {"stop", (PyCFunction)ZCross_stop, METH_NOARGS, "Stops computing."},
 {"setThresh", (PyCFunction)ZCross_setThresh, METH_O, "Sets the threshold factor."},
@@ -1216,7 +1184,450 @@ ZCross_members,                                 /* tp_members */
 0,                                              /* tp_descr_get */
 0,                                              /* tp_descr_set */
 0,                                              /* tp_dictoffset */
-(initproc)ZCross_init,                          /* tp_init */
+0,                          /* tp_init */
 0,                                              /* tp_alloc */
 ZCross_new,                                     /* tp_new */
 };
+
+static int
+min_elem_pos(MYFLT *buf, int size ) {
+    int i;
+    int pos = 0;
+    for (i=1; i<size; i++) {
+        if (buf[i] < buf[pos])
+            pos = i;
+    }
+    return pos;
+}
+
+static MYFLT
+quadraticInterpolation(MYFLT *buf, int period, int size) {
+    int x0, x2;
+    MYFLT pitch, s0, s1, s2;
+    x0 = period < 1 ? period : period - 1;
+    x2 = period + 1 < size ? period + 1 : period;
+    if (x0 == period)
+        pitch = buf[period] <= buf[x2] ? period : x2;
+    else if (x2 == period)
+        pitch = buf[period] <= buf[x0] ? period : x0;
+    else {
+        s0 = buf[x0];
+        s1 = buf[period];
+        s2 = buf[x2];
+        pitch = period + 0.5 * (s2 - s0) / (s2 - 2.0 * s1 + s0);
+    }
+    return pitch;
+}
+
+/************/
+/* Yin */
+/************/
+typedef struct {
+    pyo_audio_HEAD
+    PyObject *input;
+    Stream *input_stream;
+    MYFLT *input_buffer;
+    MYFLT *yin_buffer;
+    int winsize;
+    int halfsize;
+    int input_count;
+    MYFLT tolerance;
+    MYFLT pitch;
+    MYFLT minfreq;
+    MYFLT maxfreq;
+    MYFLT cutoff;
+    MYFLT last_cutoff;
+    MYFLT y1;
+    MYFLT c2;
+    int modebuffer[2]; // need at least 2 slots for mul & add
+} Yin;
+
+static void
+Yin_process(Yin *self) {
+    int i, j, period, tau = 0;
+    MYFLT candidate, tmp = 0.0, tmp2 = 0.0, b = 0.0;
+    MYFLT *in = Stream_getData((Stream *)self->input_stream);
+    
+    if (self->cutoff != self->last_cutoff) {
+        if (self->cutoff <= 1.0)
+            self->cutoff = 1.0;
+        else if (self->cutoff >= self->sr*0.5)
+            self->cutoff = self->sr*0.5;        
+        self->last_cutoff = self->cutoff;
+        b = 2.0 - MYCOS(TWOPI * self->cutoff / self->sr);
+        self->c2 = (b - MYSQRT(b * b - 1.0));
+    }
+
+    for (i=0; i<self->bufsize; i++) {
+        self->y1 = in[i] + (self->y1 - in[i]) * self->c2;
+        self->input_buffer[self->input_count] = self->y1;
+        if (self->input_count++ == self->winsize) {
+            self->input_count = 0;
+ 
+            self->yin_buffer[0] = 1.0;
+            for (tau = 1; tau < self->halfsize; tau++) {
+                self->yin_buffer[tau] = 0.0;
+                for (j = 0; j < self->halfsize; j++) {
+                    tmp = self->input_buffer[j] - self->input_buffer[j+tau];
+                    self->yin_buffer[tau] += tmp*tmp;
+                }
+                tmp2 += self->yin_buffer[tau];
+                self->yin_buffer[tau] *= tau / tmp2;
+                period = tau - 3;
+                if (tau > 4 && (self->yin_buffer[period] < self->tolerance) &&
+                    (self->yin_buffer[period] < self->yin_buffer[period+1])) {
+                    candidate = quadraticInterpolation(self->yin_buffer, period, self->halfsize);
+                    goto founded;
+                }
+            }
+            candidate = quadraticInterpolation(self->yin_buffer, min_elem_pos(self->yin_buffer, self->halfsize), self->halfsize);
+
+        founded:
+            
+            candidate = self->sr / candidate;
+            if (candidate > self->minfreq && candidate < self->maxfreq)
+                self->pitch = candidate;           
+
+        }
+        self->data[i] = self->pitch;
+    }
+}
+
+static void Yin_postprocessing_ii(Yin *self) { POST_PROCESSING_II };
+static void Yin_postprocessing_ai(Yin *self) { POST_PROCESSING_AI };
+static void Yin_postprocessing_ia(Yin *self) { POST_PROCESSING_IA };
+static void Yin_postprocessing_aa(Yin *self) { POST_PROCESSING_AA };
+static void Yin_postprocessing_ireva(Yin *self) { POST_PROCESSING_IREVA };
+static void Yin_postprocessing_areva(Yin *self) { POST_PROCESSING_AREVA };
+static void Yin_postprocessing_revai(Yin *self) { POST_PROCESSING_REVAI };
+static void Yin_postprocessing_revaa(Yin *self) { POST_PROCESSING_REVAA };
+static void Yin_postprocessing_revareva(Yin *self) { POST_PROCESSING_REVAREVA };
+
+static void
+Yin_setProcMode(Yin *self)
+{
+    int muladdmode;
+    muladdmode = self->modebuffer[0] + self->modebuffer[1] * 10;
+    
+    self->proc_func_ptr = Yin_process;
+ 
+	switch (muladdmode) {
+        case 0:        
+            self->muladd_func_ptr = Yin_postprocessing_ii;
+            break;
+        case 1:    
+            self->muladd_func_ptr = Yin_postprocessing_ai;
+            break;
+        case 2:    
+            self->muladd_func_ptr = Yin_postprocessing_revai;
+            break;
+        case 10:        
+            self->muladd_func_ptr = Yin_postprocessing_ia;
+            break;
+        case 11:    
+            self->muladd_func_ptr = Yin_postprocessing_aa;
+            break;
+        case 12:    
+            self->muladd_func_ptr = Yin_postprocessing_revaa;
+            break;
+        case 20:        
+            self->muladd_func_ptr = Yin_postprocessing_ireva;
+            break;
+        case 21:    
+            self->muladd_func_ptr = Yin_postprocessing_areva;
+            break;
+        case 22:    
+            self->muladd_func_ptr = Yin_postprocessing_revareva;
+            break;
+    }   
+}
+
+static void
+Yin_compute_next_data_frame(Yin *self)
+{
+    (*self->proc_func_ptr)(self); 
+    (*self->muladd_func_ptr)(self);
+}
+
+static int
+Yin_traverse(Yin *self, visitproc visit, void *arg)
+{
+    pyo_VISIT
+    Py_VISIT(self->input);
+    Py_VISIT(self->input_stream);
+    return 0;
+}
+
+static int 
+Yin_clear(Yin *self)
+{
+    pyo_CLEAR
+    Py_CLEAR(self->input);
+    Py_CLEAR(self->input_stream);
+    return 0;
+}
+
+static void
+Yin_dealloc(Yin* self)
+{
+    pyo_DEALLOC
+    free(self->input_buffer);
+    free(self->yin_buffer);
+    Yin_clear(self);
+    self->ob_type->tp_free((PyObject*)self);
+}
+
+static PyObject *
+Yin_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
+{
+    int i;
+    PyObject *inputtmp, *input_streamtmp, *multmp=NULL, *addtmp=NULL;
+    Yin *self;
+    self = (Yin *)type->tp_alloc(type, 0);
+    
+    self->winsize = 1024;
+    self->halfsize = 512;
+    self->input_count = 0;
+    self->pitch = 0.;
+    self->tolerance = 0.15;
+    self->minfreq = 40;
+    self->maxfreq = 1000;
+    self->cutoff = 1000;
+    self->last_cutoff = -1.0;
+    self->y1 = self->c2 = 0.0;
+	self->modebuffer[0] = 0;
+	self->modebuffer[1] = 0;
+    
+    INIT_OBJECT_COMMON
+    Stream_setFunctionPtr(self->stream, Yin_compute_next_data_frame);
+    self->mode_func_ptr = Yin_setProcMode;
+
+    static char *kwlist[] = {"input", "tolerance", "minfreq", "maxfreq", "cutoff", "winsize", "mul", "add", NULL};
+    
+    if (! PyArg_ParseTupleAndKeywords(args, kwds, TYPE_O_FFFFIOO, kwlist, &inputtmp, &self->tolerance, &self->minfreq, &self->maxfreq, &self->cutoff, &self->winsize, &multmp, &addtmp))
+        Py_RETURN_NONE; 
+
+    INIT_INPUT_STREAM
+    
+    if (multmp) {
+        PyObject_CallMethod((PyObject *)self, "setMul", "O", multmp);
+    }
+    
+    if (addtmp) {
+        PyObject_CallMethod((PyObject *)self, "setAdd", "O", addtmp);
+    }
+    
+    PyObject_CallMethod(self->server, "addStream", "O", self->stream);
+
+    if (self->winsize % 2 == 1)
+        self->winsize += 1;
+
+    self->input_buffer = (MYFLT *)realloc(self->input_buffer, self->winsize * sizeof(MYFLT)); 
+    for (i=0; i<self->winsize; i++)
+        self->input_buffer[i] = 0.0;
+
+    self->halfsize = self->winsize / 2;
+    self->yin_buffer = (MYFLT *)realloc(self->yin_buffer, self->halfsize * sizeof(MYFLT)); 
+    for (i=0; i<self->halfsize; i++)
+        self->yin_buffer[i] = 0.0;
+       
+    (*self->mode_func_ptr)(self);
+
+    return (PyObject *)self;
+}
+
+static PyObject * Yin_getServer(Yin* self) { GET_SERVER };
+static PyObject * Yin_getStream(Yin* self) { GET_STREAM };
+static PyObject * Yin_setMul(Yin *self, PyObject *arg) { SET_MUL };	
+static PyObject * Yin_setAdd(Yin *self, PyObject *arg) { SET_ADD };	
+static PyObject * Yin_setSub(Yin *self, PyObject *arg) { SET_SUB };	
+static PyObject * Yin_setDiv(Yin *self, PyObject *arg) { SET_DIV };	
+
+static PyObject * Yin_play(Yin *self, PyObject *args, PyObject *kwds) { PLAY };
+static PyObject * Yin_stop(Yin *self) { STOP };
+
+static PyObject * Yin_multiply(Yin *self, PyObject *arg) { MULTIPLY };
+static PyObject * Yin_inplace_multiply(Yin *self, PyObject *arg) { INPLACE_MULTIPLY };
+static PyObject * Yin_add(Yin *self, PyObject *arg) { ADD };
+static PyObject * Yin_inplace_add(Yin *self, PyObject *arg) { INPLACE_ADD };
+static PyObject * Yin_sub(Yin *self, PyObject *arg) { SUB };
+static PyObject * Yin_inplace_sub(Yin *self, PyObject *arg) { INPLACE_SUB };
+static PyObject * Yin_div(Yin *self, PyObject *arg) { DIV };
+static PyObject * Yin_inplace_div(Yin *self, PyObject *arg) { INPLACE_DIV };
+
+static PyObject *
+Yin_setTolerance(Yin *self, PyObject *arg)
+{
+	if (arg == NULL) {
+		Py_INCREF(Py_None);
+		return Py_None;
+	}
+    
+	int isNumber = PyNumber_Check(arg);
+	
+	if (isNumber == 1) {
+		self->tolerance = PyFloat_AS_DOUBLE(PyNumber_Float(arg));
+	}
+  
+	Py_RETURN_NONE;
+}
+
+static PyObject *
+Yin_setMinfreq(Yin *self, PyObject *arg)
+{
+	if (arg == NULL) {
+		Py_INCREF(Py_None);
+		return Py_None;
+	}
+    
+	int isNumber = PyNumber_Check(arg);
+	
+	if (isNumber == 1) {
+		self->minfreq = PyFloat_AS_DOUBLE(PyNumber_Float(arg));
+	}
+  
+	Py_RETURN_NONE;
+}
+
+static PyObject *
+Yin_setMaxfreq(Yin *self, PyObject *arg)
+{
+	if (arg == NULL) {
+		Py_INCREF(Py_None);
+		return Py_None;
+	}
+    
+	int isNumber = PyNumber_Check(arg);
+	
+	if (isNumber == 1) {
+		self->maxfreq = PyFloat_AS_DOUBLE(PyNumber_Float(arg));
+	}
+  
+	Py_RETURN_NONE;
+}
+
+static PyObject *
+Yin_setCutoff(Yin *self, PyObject *arg)
+{
+	if (arg == NULL) {
+		Py_INCREF(Py_None);
+		return Py_None;
+	}
+    
+	int isNumber = PyNumber_Check(arg);
+	
+	if (isNumber == 1) {
+		self->cutoff = PyFloat_AS_DOUBLE(PyNumber_Float(arg));
+	}
+  
+	Py_RETURN_NONE;
+}
+
+static PyMemberDef Yin_members[] = {
+{"server", T_OBJECT_EX, offsetof(Yin, server), 0, "Pyo server."},
+{"stream", T_OBJECT_EX, offsetof(Yin, stream), 0, "Stream object."},
+{"input", T_OBJECT_EX, offsetof(Yin, input), 0, "Input sound object."},
+{"mul", T_OBJECT_EX, offsetof(Yin, mul), 0, "Mul factor."},
+{"add", T_OBJECT_EX, offsetof(Yin, add), 0, "Add factor."},
+{NULL}  /* Sentinel */
+};
+
+static PyMethodDef Yin_methods[] = {
+{"getServer", (PyCFunction)Yin_getServer, METH_NOARGS, "Returns server object."},
+{"_getStream", (PyCFunction)Yin_getStream, METH_NOARGS, "Returns stream object."},
+{"play", (PyCFunction)Yin_play, METH_VARARGS|METH_KEYWORDS, "Starts computing without sending sound to soundcard."},
+{"stop", (PyCFunction)Yin_stop, METH_NOARGS, "Stops computing."},
+{"setTolerance", (PyCFunction)Yin_setTolerance, METH_O, "Sets the tolerance factor."},
+{"setMinfreq", (PyCFunction)Yin_setMinfreq, METH_O, "Sets the minimum frequency in output."},
+{"setMaxfreq", (PyCFunction)Yin_setMaxfreq, METH_O, "Sets the maximum frequency in output."},
+{"setCutoff", (PyCFunction)Yin_setCutoff, METH_O, "Sets the input lowpass filter cutoff frequency."},
+{"setMul", (PyCFunction)Yin_setMul, METH_O, "Sets oscillator mul factor."},
+{"setAdd", (PyCFunction)Yin_setAdd, METH_O, "Sets oscillator add factor."},
+{"setSub", (PyCFunction)Yin_setSub, METH_O, "Sets inverse add factor."},
+{"setDiv", (PyCFunction)Yin_setDiv, METH_O, "Sets inverse mul factor."},
+{NULL}  /* Sentinel */
+};
+
+static PyNumberMethods Yin_as_number = {
+(binaryfunc)Yin_add,                         /*nb_add*/
+(binaryfunc)Yin_sub,                         /*nb_subtract*/
+(binaryfunc)Yin_multiply,                    /*nb_multiply*/
+(binaryfunc)Yin_div,                                              /*nb_divide*/
+0,                                              /*nb_remainder*/
+0,                                              /*nb_divmod*/
+0,                                              /*nb_power*/
+0,                                              /*nb_neg*/
+0,                                              /*nb_pos*/
+0,                                              /*(unaryfunc)array_abs,*/
+0,                                              /*nb_nonzero*/
+0,                                              /*nb_invert*/
+0,                                              /*nb_lshift*/
+0,                                              /*nb_rshift*/
+0,                                              /*nb_and*/
+0,                                              /*nb_xor*/
+0,                                              /*nb_or*/
+0,                                              /*nb_coerce*/
+0,                                              /*nb_int*/
+0,                                              /*nb_long*/
+0,                                              /*nb_float*/
+0,                                              /*nb_oct*/
+0,                                              /*nb_hex*/
+(binaryfunc)Yin_inplace_add,                 /*inplace_add*/
+(binaryfunc)Yin_inplace_sub,                 /*inplace_subtract*/
+(binaryfunc)Yin_inplace_multiply,            /*inplace_multiply*/
+(binaryfunc)Yin_inplace_div,                                              /*inplace_divide*/
+0,                                              /*inplace_remainder*/
+0,                                              /*inplace_power*/
+0,                                              /*inplace_lshift*/
+0,                                              /*inplace_rshift*/
+0,                                              /*inplace_and*/
+0,                                              /*inplace_xor*/
+0,                                              /*inplace_or*/
+0,                                              /*nb_floor_divide*/
+0,                                              /*nb_true_divide*/
+0,                                              /*nb_inplace_floor_divide*/
+0,                                              /*nb_inplace_true_divide*/
+0,                                              /* nb_index */
+};
+
+PyTypeObject YinType = {
+PyObject_HEAD_INIT(NULL)
+0,                                              /*ob_size*/
+"_pyo.Yin_base",                                   /*tp_name*/
+sizeof(Yin),                                 /*tp_basicsize*/
+0,                                              /*tp_itemsize*/
+(destructor)Yin_dealloc,                     /*tp_dealloc*/
+0,                                              /*tp_print*/
+0,                                              /*tp_getattr*/
+0,                                              /*tp_setattr*/
+0,                                              /*tp_compare*/
+0,                                              /*tp_repr*/
+&Yin_as_number,                              /*tp_as_number*/
+0,                                              /*tp_as_sequence*/
+0,                                              /*tp_as_mapping*/
+0,                                              /*tp_hash */
+0,                                              /*tp_call*/
+0,                                              /*tp_str*/
+0,                                              /*tp_getattro*/
+0,                                              /*tp_setattro*/
+0,                                              /*tp_as_buffer*/
+Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_CHECKTYPES, /*tp_flags*/
+"Yin objects. Pitch tracker using the Yin algorithm.",           /* tp_doc */
+(traverseproc)Yin_traverse,                  /* tp_traverse */
+(inquiry)Yin_clear,                          /* tp_clear */
+0,                                              /* tp_richcompare */
+0,                                              /* tp_weaklistoffset */
+0,                                              /* tp_iter */
+0,                                              /* tp_iternext */
+Yin_methods,                                 /* tp_methods */
+Yin_members,                                 /* tp_members */
+0,                                              /* tp_getset */
+0,                                              /* tp_base */
+0,                                              /* tp_dict */
+0,                                              /* tp_descr_get */
+0,                                              /* tp_descr_set */
+0,                                              /* tp_dictoffset */
+0,                          /* tp_init */
+0,                                              /* tp_alloc */
+Yin_new,                                     /* tp_new */
+};
\ No newline at end of file
