@@ -243,7 +243,7 @@ NewMatrix_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     if (! PyArg_ParseTupleAndKeywords(args, kwds, "ii|O", kwlist, &self->width, &self->height, &inittmp))
         Py_RETURN_NONE; 
     
-    self->data = (MYFLT **)realloc(self->data, (self->height + 1) * sizeof(MYFLT));
+    self->data = (MYFLT **)realloc(self->data, (self->height + 1) * sizeof(MYFLT *));
     
     for (i=0; i<(self->height+1); i++) {
         self->data[i] = (MYFLT *)malloc((self->width + 1) * sizeof(MYFLT));
@@ -481,7 +481,7 @@ static void
 MatrixRec_compute_next_data_frame(MatrixRec *self)
 {
     int i, num, num2, upBound;
-    MYFLT sclfade, val;
+    MYFLT val;
     int width = NewMatrix_getWidth((NewMatrix *)self->matrix);
     int height = NewMatrix_getHeight((NewMatrix *)self->matrix);
     int size = width * height;
@@ -506,7 +506,6 @@ MatrixRec_compute_next_data_frame(MatrixRec *self)
     }
     
     if (self->pointer < size) {   
-        sclfade = 1. / self->fadetime;
         upBound = size - self->fadeInSample;
        
         if (off == 0)
