@@ -5,7 +5,9 @@ version = sys.version_info[:2]
 os.mkdir("Resources")
 shutil.copy("PyoDoc.py", "Resources")
 shutil.copy("FlatNoteBook.py", "Resources")
-shutil.copy("Tutorial_Custom_PyoObject.py", "Resources")
+shutil.copy("Tutorial_01_RingMod.py", "Resources")
+shutil.copy("Tutorial_02_Flanger.py", "Resources")
+shutil.copy("Tutorial_03_TriTable.py", "Resources")
 shutil.copy("E-PyoIcon.ico", "Resources")
 shutil.copy("E-PyoIconDoc.ico", "Resources")
 
@@ -13,9 +15,9 @@ os.system("svn export ../examples Resources/examples/")
 os.system("svn export snippets Resources/snippets/")
 os.system("svn export styles Resources/styles/")
 
-os.system("python ..\..\pyinstaller\Configure.py")
-os.system('python ..\..\pyinstaller\Makespec.py -F -c --icon=Resources\E-PyoIcon.ico "E-Pyo.py"')
-os.system('python ..\..\pyinstaller\Build.py "E-Pyo.spec"')
+os.system("C:\Python%d%d\python ..\..\pyinstaller\Configure.py" % version)
+os.system('C:\Python%d%d\python ..\..\pyinstaller\Makespec.py -F -c --icon=Resources\E-PyoIcon.ico "E-Pyo.py"' % version)
+os.system('C:\Python%d%d\python ..\..\pyinstaller\Build.py "E-Pyo.spec"' % version)
 
 os.mkdir("E-Pyo_py%d%d" % version)
 shutil.copytree("Resources", "E-Pyo_py%d%d/Resources" % version)
